com.nervestaple.clinical.message-intermediate.interface.core


default-delimitersclj

Default set of HL7 v2 message delimiters

Default set of HL7 v2 message delimiters
sourceraw docstring

dumpclj

(dump record)

Prints a human readable version of the message record to standard out.

Prints a human readable version of the message record to standard out.
sourceraw docstring

get-segmentsclj

(get-segments record segment-id)

Returns all of the segments (those that are not part of a set) with the matching segment ID from the provided message record.

Returns all of the segments (those that are not part of a set) with the
matching segment ID from the provided message record.
sourceraw docstring

get-setclj

(get-set record set-index)

Returns the set of segment data that is at the provided index in the given message record.

Returns the set of segment data that is at the provided index in the given
message record.
sourceraw docstring

get-set-segmentclj

(get-set-segment record set-index segment-id)

Returns all of the segments from the set at the provided index that match the given segment id in the message record.

Returns all of the segments from the set at the provided index that match
the given segment id in the message record.
sourceraw docstring

hl7->parsed-messageclj

(hl7->parsed-message message-source)

Reads data from the provided source (a Reader, String, etc.) and parses that data into a map that represents the content of the message.

Reads data from the provided source (a Reader, String, etc.) and parses that
data into a map that represents the content of the message.
sourceraw docstring

hl7->recordclj

(hl7->record message)

Reads HL7 data from the provided source (a Reader, String, etc.), parses that message and returns a message record with the same data. Data segments that are part of a set are stored in on the :sets key (in order), segments that cannot be parsed are stored on the :remainder key.

Reads HL7 data from the provided source (a Reader, String, etc.), parses that
message and returns a message record with the same data. Data segments that
are part of a set are stored in on the `:sets` key (in order), segments that
cannot be parsed are stored on the `:remainder` key.
sourceraw docstring

parsed-message->recordclj

(parsed-message->record parsed-message)

Accepts a map of parsed message data and returns a message record with the same data. Data segments that are part of a set are stored in on the :sets key (in order), segments that cannot be parsed are stored on the :remainder key.

Accepts a map of parsed message data and returns a message record with the same
data. Data segments that are part of a set are stored in on the `:sets`
key (in order), segments that cannot be parsed are stored on the `:remainder`
key.
sourceraw docstring

record->hl7clj

(record->hl7 record)

Accepts a message record and returns a String with a HL7 v2 message.

Accepts a message record and returns a String with a HL7 v2 message.
sourceraw docstring

record->parsed-messageclj

(record->parsed-message record)

Accepts a message record and returns a parsed HL7 v2 message.

Accepts a message record and returns a parsed HL7 v2 message.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries