com.nervestaple.clinical.message-intermediate.message.acknowledgement


->recordclj/s≠

(->record message-header message-acknowledgement error)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.acknowledgement.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.acknowledgement.record.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.message.acknowledgement/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.message.acknowledgement/record.
sourceraw docstring

ack?clj/s

(ack? message)

Returns true if the provided message is an "acknowledgement" message (it has an MSH segment with a message type of "ACK").

Returns true if the provided message is an "acknowledgement" message (it has
an MSH segment with a message type of "ACK").
sourceraw docstring

control-id-consistent?clj/s

(control-id-consistent? message)

Returns true if the unique control identifier in MSH segment matches the control identifier in the MSA segment.

Returns true if the unique control identifier in MSH segment matches the
control identifier in the MSA segment.
sourceraw docstring

hl7->messageclj/s

(hl7->message record)

Accepts a parsed HL7 v2 acknowledgement message and returns an acknowledgement (ACK) record.

Accepts a parsed HL7 v2 acknowledgement message and returns an
acknowledgement (ACK) record.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.message.acknowledgement.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.message.acknowledgement.record, taking a map of keywords to field values.
cljs
(map->record G__25945)

Factory function for com.nervestaple.clinical.message-intermediate.message.acknowledgement/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.message.acknowledgement/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of acknowledgement (ACK) message data and returns an ACK record.

Accepts a record of acknowledgement (ACK) message data and returns an ACK
record.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries