com.nervestaple.clinical.message-intermediate.message.admit-visit


->insuranceclj

(->insurance in1)

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.admit_visit.insurance.

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.admit_visit.insurance.
raw docstring

->recordclj

(->record msh evn pid pd1 nk1 pv1 obx insurance)

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.admit_visit.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.admit_visit.record.
raw docstring

hl7->insurance-recordsclj

(hl7->insurance-records parsed-message)

hl7->recordclj

(hl7->record parsed-message)

Accepts a parsed HL7 message and returns an admit visit record.

Accepts a parsed HL7 message and returns an admit visit record.
raw docstring

insurance->hl7clj

(insurance->hl7 record)

Accepts an admit visit record and returns a vector with all of the insurance segments as parsed HL7 data.

Accepts an admit visit record and returns a vector with all of the insurance
segments as parsed HL7 data.
raw docstring

map->insuranceclj

(map->insurance m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.message.admit_visit.insurance, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.message.admit_visit.insurance, taking a map of keywords to field values.
raw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.message.admit_visit.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.message.admit_visit.record, taking a map of keywords to field values.
raw docstring

record->hl7clj

(record->hl7 record)
(record->hl7 delimiters record)

Accepts an admit visit record and returns a parsed HL7 message.

Accepts an admit visit record and returns a parsed HL7 message.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries