com.nervestaple.clinical.message-intermediate.message.dump


dump-recordclj/s

(dump-record map-in)
(dump-record map-in indent)

Returns a set of strings that represent a human-readable version of the record. If an indent value is provided it will be used to pad the front of the returned strings.

Returns a set of strings that represent a human-readable version of the
record. If an `indent` value is provided it will be used to pad the front
of the returned strings.
sourceraw docstring

dump-segmentsclj/s

(dump-segments segments)

Returns a set of strings representing a human-readable version of the provided segments.

Returns a set of strings representing a human-readable version of the provided
segments.
sourceraw docstring

dump-seqclj/s

(dump-seq dump-record-fn seq-in)
(dump-seq dump-record-fn seq-in indent)

Returns a set of strings that represent a human-readable version of the sequence of values. If an indent value is provided it will be used to pad the front of the returned strings. If a dump-record-fn is provided, records will be dumped using that function.

Returns a set of strings that represent a human-readable version of the
sequence of values. If an `indent` value is provided it will be used to pad
the front of the returned strings. If a `dump-record-fn` is provided, records
will be dumped using that function.
sourceraw docstring

dump-setsclj/s

(dump-sets sets-in)

Returns a sequence of human-readable versions of the provided set data.

Returns a sequence of human-readable versions of the provided set data.
sourceraw docstring

messageclj/s

(message message)
source

cljdoc builds & hosts documentation for Clojure/Script libraries