com.nervestaple.clinical.message-intermediate.message.observation


->recordclj/s≠

(->record msh result)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.observation.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.observation.record.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.message.observation/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.message.observation/record.
sourceraw docstring

->resultclj/s≠

(->result pid pv1 obr obx)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.observation.result.

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.observation.result.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.message.observation/result.

Positional factory function for com.nervestaple.clinical.message-intermediate.message.observation/result.
sourceraw docstring

hl7->recordclj/s

(hl7->record parsed-message)

Accepts a parsed HL7 message and returns an observation record.

Accepts a parsed HL7 message and returns an observation record.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.message.observation.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.message.observation.record, taking a map of keywords to field values.
cljs
(map->record G__27660)

Factory function for com.nervestaple.clinical.message-intermediate.message.observation/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.message.observation/record, taking a map of keywords to field values.
sourceraw docstring

map->resultclj/s≠

clj
(map->result m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.message.observation.result, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.message.observation.result, taking a map of keywords to field values.
cljs
(map->result G__27642)

Factory function for com.nervestaple.clinical.message-intermediate.message.observation/result, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.message.observation/result, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)
(record->hl7 delimiters record)

Accepts an observation record and returns a parsed HL7 message.

Accepts an observation record and returns a parsed HL7 message.
sourceraw docstring

resultcljs

source

cljdoc builds & hosts documentation for Clojure/Script libraries