com.nervestaple.clinical.message-intermediate.segment.al1


->recordclj/s≠

(->record set-id
          allergen-type
          allergen-description
          allergy-severity
          allergy-reaction
          identification-date)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.al1.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.al1.record.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.al1/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.al1/record.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts an AL1 segment of parsed HL7 data and returns an AL1 record.

Accepts an AL1 segment of parsed HL7 data and returns an AL1 record.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.al1.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.al1.record, taking a map of keywords to field values.
cljs
(map->record G__25984)

Factory function for com.nervestaple.clinical.message-intermediate.segment.al1/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.al1/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of patient allergy data and returns a map of AL1 segment data.

Accepts a record of patient allergy data and returns a map of AL1 segment
data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries