com.nervestaple.clinical.message-intermediate.segment.drg


->recordclj/s≠

clj
(->record diagnosis-related-group
          drg-assigned-date
          drg-approval-indicator
          drg-grouper-review-code
          outlier-type
          outlier-days
          outlier-cost
          drg-payor
          outlier-reimbursement
          confidential-indicator
          drg-transfer-type
          coder-name
          grouper-status
          pccl-value-code
          effective-weight
          monetary-amount
          status-patient
          grouper-software-name
          grouper-software-version
          status-financial-calculation
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record.
cljs
(->record diagnosis-related-group
          drg-assigned-date
          drg-approval-indicator
          drg-grouper-review-code
          outlier-type
          outlier-days
          outlier-cost
          drg-payor
          outlier-reimbursement
          confidential-indicator
          drg-transfer-type
          coder-name
          grouper-status
          pccl-value-code
          effective-weight
          monetary-amount
          status-patient
          grouper-software-name
          grouper-software-version
          status-financial-calculation
          relative-discount
          basic-charge
          total-charge
          discount
          calculated-days
          status-gender
          status-age
          status-length-of-stay
          status-same-day-flag
          status-separation-mode
          status-weight-birth
          status-respiration-minutes
          status-admission)

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.drg/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.drg/record.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts a DRG segment of parsed HL7 segment data and returns a DRG record.

Accepts a DRG segment of parsed HL7 segment data and returns a DRG record.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record, taking a map of keywords to field values.
cljs
(map->record G__26020)

Factory function for com.nervestaple.clinical.message-intermediate.segment.drg/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.drg/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of diagnosis related group data and returns a map of DRG segment data.

Accepts a record of diagnosis related group data and returns a map of DRG
segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries