com.nervestaple.clinical.message-intermediate.segment.err


->eldclj/s≠

(->eld segment-id segment-sequence field-position code-error)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.eld.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.eld.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.err/eld.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.err/eld.
sourceraw docstring

->erlclj/s≠

(->erl segment-id
       segment-sequence
       field-position
       field-repetition
       component-number
       sub-component-number)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.erl.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.erl.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.err/erl.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.err/erl.
sourceraw docstring

->recordclj/s≠

(->record error-code-location
          error-location
          error-code
          severity
          application-error-code
          application-error-parameter
          diagnostic-information
          user-message)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.record.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.err/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.err/record.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

eldcljs

source

eld->fieldclj/s

(eld->field eld-record)

Accepts one or a sequence of ELD records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of ELD records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

erlcljs

source

erl->fieldclj/s

(erl->field erl-record)

Accepts one or a sequence of ERL records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of ERL records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

field->eldclj/s

(field->eld field)

Accepts an HL7 v2 field of ELD data and returns a single ELD record or a sequence of records or nil.

Accepts an HL7 v2 field of ELD data and returns a single ELD record or a
sequence of records or nil.
sourceraw docstring

field->erlclj/s

(field->erl field)

Accepts an HL7 v2 field of ERL data and returns a single ERL record or a sequence of records or nil.

Accepts an HL7 v2 field of ERL data and returns a single ERL record or a
sequence of records or nil.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts an ERR segment of parsed HL7 data and retirns an error record.

Accepts an ERR segment of parsed HL7 data and retirns an error record.
sourceraw docstring

map->eldclj/s≠

clj
(map->eld m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.eld, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.eld, taking a map of keywords to field values.
cljs
(map->eld G__25882)

Factory function for com.nervestaple.clinical.message-intermediate.segment.err/eld, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.err/eld, taking a map of keywords to field values.
sourceraw docstring

map->erlclj/s≠

clj
(map->erl m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.erl, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.erl, taking a map of keywords to field values.
cljs
(map->erl G__25903)

Factory function for com.nervestaple.clinical.message-intermediate.segment.err/erl, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.err/erl, taking a map of keywords to field values.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.record, taking a map of keywords to field values.
cljs
(map->record G__25924)

Factory function for com.nervestaple.clinical.message-intermediate.segment.err/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.err/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of error (ERR) segment data and returns an ERR record.

Accepts a record of error (ERR) segment data and returns an ERR record.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries