(->fc financial-class effective-date)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.fc.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.fc.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/fc.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/fc.
(->jcc job-code job-class job-description)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.jcc.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.jcc.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/jcc.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/jcc.
(->record set-id
guarantor-number
guarantor-name
guarantor-spouse-name
guarantor-address
guarantor-phone-home
guarantor-phone-business
guarantor-birth-date
guarantor-administrative-sex
guarantor-type
guarantor-relationship
guarantor-social-security-number
guarantor-begin-date
guarantor-end-date
guarantor-priority
guarantor-employer-name
guarantor-employer-address
guarantor-employer-phone
guarantor-employee-identifier
guarantor-employment-status
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.record.
(->record
set-id
guarantor-number
guarantor-name
guarantor-spouse-name
guarantor-address
guarantor-phone-home
guarantor-phone-business
guarantor-birth-date
guarantor-administrative-sex
guarantor-type
guarantor-relationship
guarantor-social-security-number
guarantor-begin-date
guarantor-end-date
guarantor-priority
guarantor-employer-name
guarantor-employer-address
guarantor-employer-phone
guarantor-employee-identifier
guarantor-employment-status
guarantor-organization
guarantor-billing-hold-flag
guarantor-credit-rating
guarantor-death-date
guarantor-death-flag
guarantor-charge-adjustment
guarantor-household-annual-income
guarantor-household-size
guarantor-employer-identifier
guarantor-marital-status-code
guarantor-hire-effective-date
employment-stop-date
living-dependency-coded
ambulatory-status
citizenship
primary-language
living-arrangement
publicity-code
protection-indicator
student-indicator-coded
religion
mother-maiden-name
nationality
ethnic-group
contact-person
contact-person-phone
contact-reason
job-title
job-code-class
guarantor-employer-organization
handicap-coded
job-status
guarantor-financial-class
guarantor-race
guarantor-birth-place
vip-indicator)Positional factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/record.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(fc->field record)Accepts one or a sequence of FC records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of FC records and returns a value, collection or map of HL7 v2 data.
(field->fc field)Accepts an HL7 v2 field of FCC data and returns a single FCC record, a sequence of records or nil.
Accepts an HL7 v2 field of FCC data and returns a single FCC record, a sequence of records or nil.
(field->jcc field)Accepts an HL7 v2 field of JCC data and returns a single JCC record, a sequence of records or nil.
Accepts an HL7 v2 field of JCC data and returns a single JCC record, a sequence of records or nil.
(hl7->record segment)Accepts a GT1 segment of parsed HL7 segment data and returns a GT1 record.
Accepts a GT1 segment of parsed HL7 segment data and returns a GT1 record.
(jcc->field record)Accepts one or a sequence of JCC records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of JCC records and returns a value, collection or map of HL7 v2 data.
(map->fc m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.fc, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.fc, taking a map of keywords to field values.
(map->fc G__26077)Factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/fc, taking a map of keywords to field values.
Factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/fc, taking a map of keywords to field values.
(map->jcc m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.jcc, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.jcc, taking a map of keywords to field values.
(map->jcc G__26056)Factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/jcc, taking a map of keywords to field values.
Factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/jcc, taking a map of keywords to field values.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.record, taking a map of keywords to field values.
(map->record G__26098)Factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/record, taking a map of keywords to field values.
Factory function for com.nervestaple.clinical.message-intermediate.segment.gt1/record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of patient guarantor data and returns a map of GT1 segment data.
Accepts a record of patient guarantor data and returns a map of GT1 segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |