com.nervestaple.clinical.message-intermediate.segment.in1


->auiclj/s≠

(->aui authorization-number date source)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.in1/aui.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.in1/aui.
sourceraw docstring

->recordclj/s≠

clj
(->record set-id
          plan-id
          company-id
          company-name
          company-address
          company-contact
          company-telephone
          group-number
          group-name
          group-employee-id
          group-employee-name
          plan-effective-date
          plan-expiration-date
          authorization-info
          plan-type
          insured-name
          insured-relationship
          insured-birth-date
          insured-address
          assignment-of-benefits
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record.
cljs
(->record
  set-id
  plan-id
  company-id
  company-name
  company-address
  company-contact
  company-telephone
  group-number
  group-name
  group-employee-id
  group-employee-name
  plan-effective-date
  plan-expiration-date
  authorization-info
  plan-type
  insured-name
  insured-relationship
  insured-birth-date
  insured-address
  assignment-of-benefits
  coordination-of-benefits
  coordination-of-benefits-priority
  notice-admission-flag
  notice-admission-date
  report-eligibility-flag
  report-eligibility-date
  release-info-code
  pre-admit-cert
  verification-date
  verification-person
  agreement-type-code
  billing-status
  lifetime-reserve-days
  delay-before-lr-day
  company-plan-code
  policy-number
  policy-deductible
  policy-limit-amount
  policy-limit-days
  room-rate-semi-private
  room-rate-private
  insured-employment-status
  insured-administrative-gender
  insured-employer-address
  verification-status
  prior-insurance-plan-id
  coverage-type
  handicap
  insured-id-number)

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.in1/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.in1/record.
sourceraw docstring

auicljs

source

aui->fieldclj/s

(aui->field record)

Accepts one or a sequence of AUI records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of AUI records and returns a value, collection or
map of HL7 v2 data.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

field->auiclj/s

(field->aui field)

Accepts an HL7 v2 field of AUI data and returns a single record, a sequence of records or nil.

Accepts an HL7 v2 field of AUI data and returns a single record, a sequence
of records or nil.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts a segment of parsed HL7 data and returns an IN1 record.

Accepts a segment of parsed HL7 data and returns an IN1 record.
sourceraw docstring

map->auiclj/s≠

clj
(map->aui m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui, taking a map of keywords to field values.
cljs
(map->aui G__26116)

Factory function for com.nervestaple.clinical.message-intermediate.segment.in1/aui, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.in1/aui, taking a map of keywords to field values.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record, taking a map of keywords to field values.
cljs
(map->record G__26137)

Factory function for com.nervestaple.clinical.message-intermediate.segment.in1/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.in1/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of insurance data and returns a map of IN1 segment data.

Accepts a record of insurance data and returns a map of IN1 segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries