com.nervestaple.clinical.message-intermediate.segment.java-date-time


format-timeclj

(format-time time)

Formats the provided date and time into an HL7 messaging date.

Formats the provided date and time into an HL7 messaging date.
sourceraw docstring

parse-dateclj

(parse-date date)

Parses a hypen separated date.

Parses a hypen separated date.
sourceraw docstring

parse-timestampclj

(parse-timestamp timestamp-in)

Parses an HL7 v2 formatted field or string with a date or timestamp into a local date, local date time or a zoned local date and time. If the value cannot be parsed, it is returned unaltered.

Parses an HL7 v2 formatted field or string with a date or timestamp into a
local date, local date time or a zoned local date and time. If the value
cannot be parsed, it is returned unaltered.
sourceraw docstring

unwrap-fieldclj

(unwrap-field field)

Accepts a field of parsed HL7 v2 data, which may be one item of data or a sequence of data items, and unwraps either the single item or each item in the sequence and returns the data either the single item or vector of items.

Accepts a field of parsed HL7 v2 data, which may be one item of data or a
sequence of data items, and unwraps either the single item or each item in the
sequence and returns the data either the single item or vector of items.
sourceraw docstring

zoned-date-timeclj

(zoned-date-time)

Returns the current date and time in the current timezone.

Returns the current date and time in the current timezone.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries