com.nervestaple.clinical.message-intermediate.segment.lookups


acknowledgement-code-by-keyclj

(acknowledgement-code-by-key key-string)

Returns the matching code value for the provided textual acknowledment code or nil if the value has no matches.

Returns the matching code value for the provided textual acknowledment code or
nil if the value has no matches.
raw docstring

acknowledgement-code-by-valueclj

(acknowledgement-code-by-value key-vector)

Returns the matching textual string for the provided acknowledgement code or nil if no matches are found.

Returns the matching textual string for the provided acknowledgement code or
nil if no matches are found.
raw docstring

acknowledgement-code-dataclj

Sequence of acknowledgement types (where the first key represents the "official" value) and the matching code value.

Sequence of acknowledgement types (where the first key represents the
"official" value) and the matching code value.
raw docstring

acknowledgement-error-code-by-keyclj

(acknowledgement-error-code-by-key key-string)

Returns the matching code value for the provided textual acknowledment error code or nil if the value has no matches.

Returns the matching code value for the provided textual acknowledment error
code or nil if the value has no matches.
raw docstring

acknowledgement-error-code-by-valueclj

(acknowledgement-error-code-by-value key-vector)

Returns the matching textual string for the provided acknowledgement error code or nil if no matches are found.

Returns the matching textual string for the provided acknowledgement error code
or nil if no matches are found.
raw docstring

acknowledgement-error-code-dataclj

Sequence of acknowledgement error codes (where the first key represents the "official" value) and the matching code value.

Sequence of acknowledgement error codes (where the first key represents the
"official" value) and the matching code value.
raw docstring

acknowledgement-type-by-keyclj

(acknowledgement-type-by-key key-string)

Returns the matching code value for the provided textual acknowledment type or nil if the value has no matches.

Returns the matching code value for the provided textual acknowledment type or
nil if the value has no matches.
raw docstring

acknowledgement-type-by-valueclj

(acknowledgement-type-by-value key-vector)

Returns the matching textual string for the provided acknowledgement type or nil if no matches are found.

Returns the matching textual string for the provided acknowledgement type or
nil if no matches are found.
raw docstring

acknowledgement-type-dataclj

Sequence of acknowledment type data (where the first key represents the "official" value) and the matching code value.

Sequence of acknowledment type data (where the first key represents the
"official" value) and the matching code value.
raw docstring

address-by-keyclj

(address-by-key key-string)

Returns the matching address type code for the provided key or nil if there are no matches.

Returns the matching address type code for the provided key or nil if there are
no matches.
raw docstring

address-by-valueclj

(address-by-value key-string)

Returns the matching address value for the provided code or the value for "C" code (current) if there are no matches.

Returns the matching address value for the provided code or the value for
"C" code (current) if there are no matches.
raw docstring

address-type-dataclj

Sequence of address type keys (where the first key represents the "official" or most widely used key) and the matching code value.

Sequence of address type keys (where the first key represents the "official"
or most widely used key) and the matching code value.
raw docstring

convert-genderclj

(convert-gender gender)

Converts a textual gender value to the matching HL7 code

Converts a textual gender value to the matching HL7 code
raw docstring

convert-raceclj

(convert-race race)

Converts a textual race value to the matching HL7 values

Converts a textual race value to the matching HL7 values
raw docstring

ethnicity-by-keyclj

(ethnicity-by-key key-string)

Returns the matching code value for the provided textual ethnicity or the code for "Unknown" of the value has no matches.

Returns the matching code value for the provided textual ethnicity or the code
for "Unknown" of the value has no matches.
raw docstring

ethnicity-by-valueclj

(ethnicity-by-value key-string)

Returns the matching textual string for the provided ethnicity code or the textual value for "U" if no matches are found.

Returns the matching textual string for the provided ethnicity code or the
textual value for "U" if no matches are found.
raw docstring

ethnicity-dataclj

Sequence of ethnicity types (where the first key represents the "official" value) and the matching code value.

Sequence of ethnicity types (where the first key represents the "official"
value) and the matching code value.
raw docstring

gender-by-keyclj

(gender-by-key key-string)

Returns the matching code value for the provided textual gender value or the code for "Unknown" of the value has no matches.

Returns the matching code value for the provided textual gender value or the
code for "Unknown" of the value has no matches.
raw docstring

gender-by-valueclj

(gender-by-value key-string)

Returns the matching textual string for the provided gender code or the textual value for "U" if no matches are found.

Returns the matching textual string for the provided gender code or the
textual value for "U" if no matches are found.
raw docstring

gender-dataclj

Sequence of gender types (where the first key represents the "official" value) and the matching code value.

Sequence of gender types (where the first key represents the "official"
value) and the matching code value.
raw docstring

key-by-valueclj

(key-by-value value-seq default-value value)

Accepts a sequence of value maps (in the format {:keys [...] :code "XXX"}) and returns the first key value for the map that contains the provided value under its :code value. If there are no matches, the first key value for the map with default-value in its :key value is returned If there are no matches and there is no default-value, the value is returned.

Note that the value could be a string or a vector of strings: if a string is supplied and the value under the :code key is a vector then the string must match the first item in that vector; if a vector is supplied it must match the entire value under the :code key.

Accepts a sequence of value maps (in the format {:keys [...] :code "XXX"})
and returns the first key value for the map that contains the provided value
under its :code value. If there are no matches, the first key value for the
map with default-value in its :key value is returned If there are no matches
and there is no default-value, the value is returned.

Note that the value could be a string or a vector of strings: if a string is
supplied and the value under the :code key is a vector then the string must
match the first item in that vector; if a vector is supplied it must match the
entire value under the :code key.
raw docstring

marital-status-by-keyclj

(marital-status-by-key key-string)

Returns the matching code value for the provided textual marital status or the code for "Unknown" of the value has no matches.

Returns the matching code value for the provided textual marital status or the
code for "Unknown" of the value has no matches.
raw docstring

marital-status-by-valueclj

(marital-status-by-value key-string)

Returns the matching textual string for the provided marital status code or the textual value for "U" if no matches are found.

Returns the matching textual string for the provided marital status code or
the textual value for "U" if no matches are found.
raw docstring

marital-status-dataclj

Sequence of martial type keys (where the first key represents the "official" value) and the matching code value.

Sequence of martial type keys (where the first key represents the "official"
value) and the matching code value.
raw docstring

message-structure->stringclj

(message-structure->string key-vector)

Returns the matching textual string for the provided message structure code or nil if the provided value has no matches.

Returns the matching textual string for the provided message structure code or
nil if the provided value has no matches.
raw docstring

message-structure-dataclj

Sequence of message structure values (where the first key represents the "official" value) and their matching code values.

Sequence of message structure values (where the first key represents the
"official" value) and their matching code values.
raw docstring

message-typesclj

Map of MSH message types

Map of MSH message types
raw docstring

patient-class-by-keyclj

(patient-class-by-key key-string)

Returns the matching code value for the provided textual patient class value or the code for "Unknown" of the value has no matches.

Returns the matching code value for the provided textual patient class value or
the code for "Unknown" of the value has no matches.
raw docstring

patient-class-by-valueclj

(patient-class-by-value key-string)

Returns the matching textual string for the provided patient class code or the textual value for "U" if no matches are found.

Returns the matching textual string for the provided patient class code or the
textual value for "U" if no matches are found.
raw docstring

patient-class-dataclj

Sequence of patient class types (where the first key represents the "official" value) and the matching code value.

Sequence of patient class types (where the first key represents the
"official" value) and the matching code value.
raw docstring

processing-id-by-keyclj

(processing-id-by-key key-string)

Returns the matching code value for the provided textual processing ID value or nil if the value has no matches.

Returns the matching code value for the provided textual processing ID value or
nil if the value has no matches.
raw docstring

processing-id-by-valueclj

(processing-id-by-value key-vector)

Returns the matching textual string for the provided processing ID or nil if no matches are found.

Returns the matching textual string for the provided processing ID or nil if no
matches are found.
raw docstring

processing-id-dataclj

Sequence of processing identifier data (where the first key represents the "official" value) and the matching code values.

Sequence of processing identifier data (where the first key represents the
"official" value) and the matching code values.
raw docstring

processing-mode-by-keyclj

(processing-mode-by-key key-string)

Returns the matching code value for the provided textual processing mode value or nil if the value has no matches.

Returns the matching code value for the provided textual processing mode value
or nil if the value has no matches.
raw docstring

processing-mode-by-valueclj

(processing-mode-by-value key-vector)

Returns the matching textual string for the provided processing mode or nil if no matches are found.

Returns the matching textual string for the provided processing mode or nil if
no matches are found.
raw docstring

processing-mode-dataclj

Sequence of processing mode data (where the first key represents the "official" value) and the matching code values.

Sequence of processing mode data (where the first key represents the
"official" value) and the matching code values.
raw docstring

race-by-keyclj

(race-by-key key-string)

Returns the matching vector with the code value for the provided textual race value or the vector with the code value for "Other" of the value has no matches.

Returns the matching vector with the code value for the provided textual race
value or the vector with the code value for "Other" of the value has no
matches.
raw docstring

race-by-valueclj

(race-by-value key-vector)

Returns the matching textual string for the provided vector of race code data or the vector with the code value for "Other" if no matches are found.

Returns the matching textual string for the provided vector of race code data
or the vector with the code value for "Other" if no matches are found.
raw docstring

race-dataclj

Sequence of race types (where the first key represents the "official" value) and the matching vector of code values. Note that the code values here are not authoritative, they represent the values that appear to be the most popular.

Sequence of race types (where the first key represents the "official" value)
and the matching vector of code values. Note that the code values here are not
authoritative, they represent the values that appear to be the most popular.
raw docstring

rxa-action-code-by-keyclj

(rxa-action-code-by-key key-string)

Returns the matching code value for the provided textual RXA value or nil if the value has no matches.

Returns the matching code value for the provided textual RXA value or nil if
the value has no matches.
raw docstring

rxa-action-code-by-valueclj

(rxa-action-code-by-value key-vector)

Returns the matching textual string for the provided RXA value or nil if no matches are found.

Returns the matching textual string for the provided RXA value or nil if no
matches are found.
raw docstring

rxa-action-code-dataclj

Sequence of RXA action code values (where the first key represents the "official" value) and the matching code values.

Sequence of RXA action code values (where the first key represents the
"official" value) and the matching code values.
raw docstring

rxa-completion-status-by-keyclj

(rxa-completion-status-by-key key-string)

Returns the matching code value for the provided textual RXA completion status or nil if the value has no matches.

Returns the matching code value for the provided textual RXA completion status
or nil if the value has no matches.
raw docstring

rxa-completion-status-by-valueclj

(rxa-completion-status-by-value key-vector)

Returns the matching textual string for the provided RXA completion status or nil if no matches are found.

Returns the matching textual string for the provided RXA completion status or
nil if no matches are found.
raw docstring

rxa-completion-status-dataclj

Sequence of RXA completion status values (where the first key represents the "official" value) and the matching code values.

Sequence of RXA completion status values (where the first key represents the
"official" value) and the matching code values.
raw docstring

rxa-pharmacy-order-type-by-keyclj

(rxa-pharmacy-order-type-by-key key-string)

Returns the matching code value for the provided textual RXA pharmacy order type code or nil if the value has no matches.

Returns the matching code value for the provided textual RXA pharmacy order
type code or nil if the value has no matches.
raw docstring

rxa-pharmacy-order-type-by-valueclj

(rxa-pharmacy-order-type-by-value key-vector)

Returns the matching textual string for the provided RXA pharmacy order type or nil if no matches are found.

Returns the matching textual string for the provided RXA pharmacy order type
or nil if no matches are found.
raw docstring

rxa-pharmacy-order-type-dataclj

Sequence of RXA pharmacy order type values (where the first key represents the "official" value) and the matching code values.

Sequence of RXA pharmacy order type values (where the first key represents the
"official" value) and the matching code values.
raw docstring

string->message-structureclj

(string->message-structure key-string)

Returns the matching code value for the provided message structure textual string or nil if the provided value has no matches.

Returns the matching code value for the provided message structure textual
string or nil if the provided value has no matches.
raw docstring

string->trigger-eventclj

(string->trigger-event key-string)

Returns the matching code value for the provided trigger event textual string or nil if the provided value has no matches.

Returns the matching code value for the provided trigger event textual string
or nil if the provided value has no matches.
raw docstring

trigger-event->stringclj

(trigger-event->string key-vector)

Returns the matching textual string for the provided trigger event code or nil if the provided value has no matches.

Returns the matching textual string for the provided trigger event code or nil
if the provided value has no matches.
raw docstring

trigger-event-dataclj

Sequence of trigger event values (where the first key represents the "official" value) and the matching code value.

Sequence of trigger event values (where the first key represents the
"official" value) and the matching code value.
raw docstring

value-for-keyclj

(value-for-key value-seq default-key key-string)

Accepts a sequence of value maps (in the format {:keys [...] :code "XXX"}) and returns the :code value for the map that contains the provided key-string in under its :key value. If there are no matches, the :code value for the map with default-key in its :key value is returned. If there are no matches and there is no default key, the key string is returned.

Accepts a sequence of value maps (in the format {:keys [...] :code "XXX"})
and returns the :code value for the map that contains the provided key-string
in under its :key value. If there are no matches, the :code value for the map
with default-key in its :key value is returned. If there are no matches and
there is no default key, the key string is returned.
raw docstring

xtn-equip-by-keyclj

(xtn-equip-by-key key-string)

Returns the matching vector with the code value for the provided textual XTN equipment type code value or nil if the value has no matches.

Returns the matching vector with the code value for the provided textual XTN
equipment type code value or nil if the value has no matches.
raw docstring

xtn-equip-by-valueclj

(xtn-equip-by-value key-vector)

Returns the matching textual string for the provided XTN use code or nil if no matches are found.

Returns the matching textual string for the provided XTN use code or nil if no
matches are found.
raw docstring

xtn-equipment-type-dataclj

Sequence of telecommunication equipement type (where the first key represents the "official" value) and the matching string or vector of code values.

Sequence of telecommunication equipement type (where the first key represents
the "official" value) and the matching string or vector of code values.
raw docstring

xtn-use-by-keyclj

(xtn-use-by-key key-string)

Returns the matching vector with the code value for the provided textual XTN use code value or the vector with the code value for "Other" if the value has no matches.

Returns the matching vector with the code value for the provided textual XTN
use code value or the vector with the code value for "Other" if the value
has no matches.
raw docstring

xtn-use-by-valueclj

(xtn-use-by-value key-vector)

Returns the matching textual string for the provided XTN use code or the code value for "Other" if no matches are found.

Returns the matching textual string for the provided XTN use code or the code value for "Other"
if no matches are found.
raw docstring

xtn-use-code-dataclj

Sequence of telecommunication use type (wher the first key represents the "official" value) and the matching string or vector of code values.

Sequence of telecommunication use type (wher the first key represents the
"official" value) and the matching string or vector of code values.
raw docstring

yes-no-by-keyclj

(yes-no-by-key key-string)

Returns the matching code value for the provided textual yes/no value or the code for "No" of the value has no matches.

Returns the matching code value for the provided textual yes/no value or the
code for "No" of the value has no matches.
raw docstring

yes-no-by-valueclj

(yes-no-by-value key-string)

Returns the matching textual string for the provided yes/no code or the textual value for "N" if no matches are found.

Returns the matching textual string for the provided yes/no code or the textual
value for "N" if no matches are found.
raw docstring

yes-no-dataclj

Sequence of yes or no type keys (where the first key represents the "official" value) and the matching code value.

Sequence of yes or no type keys (where the first key represents the
"official" value) and the matching code value.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries