com.nervestaple.clinical.message-intermediate.segment.mrg


->recordclj/s≠

(->record prior-patient-id-list
          prior-alternate-id
          prior-patient-account-number
          prior-patient-id
          prior-visit-number
          prior-alternate-visit-id
          prior-patient-name)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.mrg.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.mrg.record.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.mrg/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.mrg/record.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts an MRG segment of parsed HL7 segment data and returns an MRG record.

Accepts an MRG segment of parsed HL7 segment data and returns an MRG record.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.mrg.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.mrg.record, taking a map of keywords to field values.
cljs
(map->record G__26155)

Factory function for com.nervestaple.clinical.message-intermediate.segment.mrg/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.mrg/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of merge data and returns a map of MRG segment data.

Accepts a record of merge data and returns a map of MRG segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries