com.nervestaple.clinical.message-intermediate.segment.msa


->recordclj/s≠

(->record acknowledgement-code
          message-control-id
          message
          expected-sequence-number
          delayed-acknowledgement-type
          error-condition
          message-waiting-number
          message-waiting-priority)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msa.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msa.record.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msa/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msa/record.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accpets an MSA segment of parsed HL7 data and returns a message acknowledgement record.

Accpets an MSA segment of parsed HL7 data and returns a message acknowledgement
record.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msa.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msa.record, taking a map of keywords to field values.
cljs
(map->record G__25763)

Factory function for com.nervestaple.clinical.message-intermediate.segment.msa/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.msa/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of message acknowledgement (MSA) segment data and returns an MSA record.

Accepts a record of message acknowledgement (MSA) segment data and returns an
MSA record.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries