com.nervestaple.clinical.message-intermediate.segment.msh


->msgclj/s≠

(->msg msg-code msg-trigger msg-structure)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msh/msg.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msh/msg.
sourceraw docstring

->ptclj/s≠

(->pt processing-id processing-mode)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msh/pt.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msh/pt.
sourceraw docstring

->recordclj/s≠

clj
(->record delimiters
          sending-application
          sending-facility
          receiving-application
          receiving-facility
          message-created
          security
          message-type
          message-control-id
          message-processing-id
          message-version-id
          sequence-number
          continuation-pointer
          accept-acknowledgement-type
          application-acknowledgement-type
          country-code
          character-set
          principal-language
          alternate-character-set
          message-profile-indicator
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record.
cljs
(->record delimiters
          sending-application
          sending-facility
          receiving-application
          receiving-facility
          message-created
          security
          message-type
          message-control-id
          message-processing-id
          message-version-id
          sequence-number
          continuation-pointer
          accept-acknowledgement-type
          application-acknowledgement-type
          country-code
          character-set
          principal-language
          alternate-character-set
          message-profile-indicator
          sending-responsible-organization
          receiving-responsible-organization
          sending-network-address
          receiving-network-address)

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msh/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msh/record.
sourceraw docstring

->vidclj/s≠

(->vid version-id international-code international-version-id)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msh/vid.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.msh/vid.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

default-delimitersclj/s

Map with our default set of delimiters

Map with our default set of delimiters
sourceraw docstring

field->msgclj/s

(field->msg field)

Accepts an HL7 v2 field of MSG data and returns a single MSG record or a sequence of records or nil.

Accepts an HL7 v2 field of MSG data and returns a single MSG record or a
sequence of records or nil.
sourceraw docstring

field->ptclj/s

(field->pt field)

Accepts an HL7 v2 field of PT data and returns a single PT record or a sequence of records or nil.

Accepts an HL7 v2 field of PT data and returns a single PT record or a sequence
of records or nil.
sourceraw docstring

field->vidclj/s

(field->vid field)

Accepts an HL7 v2 field of VID data and returns a single VID record or a sequence of records or nil.

Accepts an HL7 v2 field of VID data and returns a single VID record or a
sequence of records or nil.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment & [delimiters])

Accepts an MSH segment of parsed HL7 data and retirns a record.

Accepts an MSH segment of parsed HL7 data and retirns a record.
sourceraw docstring

map->msgclj/s≠

clj
(map->msg m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg, taking a map of keywords to field values.
cljs
(map->msg G__25825)

Factory function for com.nervestaple.clinical.message-intermediate.segment.msh/msg, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.msh/msg, taking a map of keywords to field values.
sourceraw docstring

map->ptclj/s≠

clj
(map->pt m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt, taking a map of keywords to field values.
cljs
(map->pt G__25783)

Factory function for com.nervestaple.clinical.message-intermediate.segment.msh/pt, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.msh/pt, taking a map of keywords to field values.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record, taking a map of keywords to field values.
cljs
(map->record G__25849)

Factory function for com.nervestaple.clinical.message-intermediate.segment.msh/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.msh/record, taking a map of keywords to field values.
sourceraw docstring

map->vidclj/s≠

clj
(map->vid m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid, taking a map of keywords to field values.
cljs
(map->vid G__25804)

Factory function for com.nervestaple.clinical.message-intermediate.segment.msh/vid, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.msh/vid, taking a map of keywords to field values.
sourceraw docstring

msgcljs

source

msg->fieldclj/s

(msg->field msg-record)

Accepts one or a sequence of MSG records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of MSG records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

ptcljs

source

pt->fieldclj/s

(pt->field pt-record)

Accepts one or a sequence of PT records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of PT records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

pt-debugclj/s

source

pt-productionclj/s

source

pt-testclj/s

source

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of message header (MSH) segment data and returns a map of MSH segment data.

Accepts a record of message header (MSH) segment data and returns a map of MSH
segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

string->vidclj/s

(string->vid version-id)

Accepts a string with version identifier and returns a VID record.

Accepts a string with version identifier and returns a VID record.
sourceraw docstring

vidcljs

source

vid->fieldclj/s

(vid->field vid-record)

Accepts one or a sequence of VID records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of VID records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries