com.nervestaple.clinical.message-intermediate.segment.nk1


->jccclj/s≠

(->jcc job-code job-class)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.nk1/jcc.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.nk1/jcc.
sourceraw docstring

->recordclj/s≠

clj
(->record set-id
          associated-party-name
          relationship
          address
          phone-number
          business-phone-number
          contact-role
          start-date
          end-date
          associated-party-job-title
          associated-party-job-code
          associated-party-employee-number
          associated-party-organization-name
          martial-status
          administrative-gender
          birth-date
          living-dependency
          ambulatory-status
          citizenship
          primary-language
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record.
cljs
(->record
  set-id
  associated-party-name
  relationship
  address
  phone-number
  business-phone-number
  contact-role
  start-date
  end-date
  associated-party-job-title
  associated-party-job-code
  associated-party-employee-number
  associated-party-organization-name
  martial-status
  administrative-gender
  birth-date
  living-dependency
  ambulatory-status
  citizenship
  primary-language
  living-arrangement
  publicity-code
  protection-indicator
  student-indicator
  religion
  mother-maiden-name
  nationality
  ethnic-group
  contact-reason
  contact-person-name
  contact-person-telephone
  contact-person-address
  associated-party-identifiers
  job-status
  race
  handicap
  contact-person-social-security-number)

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.nk1/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.nk1/record.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

field->jccclj/s

(field->jcc field)

Accepts an HL7 v2 field of JCC data and returns a single JCC record, a sequence of records or nil.

Accepts an HL7 v2 field of JCC data and returns a single JCC record, a
sequence of records or nil.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts an NK1 segment of parsed HL7 segment data and returns an NK1 record.

Accepts an NK1 segment of parsed HL7 segment data and returns an NK1 record.
sourceraw docstring

jcccljs

source

jcc->fieldclj/s

(jcc->field record)

Accepts one or a sequence of JCC records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of JCC records and returns a value, collection or
map of HL7 v2 data.
sourceraw docstring

map->jccclj/s≠

clj
(map->jcc m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc, taking a map of keywords to field values.
cljs
(map->jcc G__26173)

Factory function for com.nervestaple.clinical.message-intermediate.segment.nk1/jcc, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.nk1/jcc, taking a map of keywords to field values.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record, taking a map of keywords to field values.
cljs
(map->record G__26194)

Factory function for com.nervestaple.clinical.message-intermediate.segment.nk1/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.nk1/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of patient next of kin data and returns a map of NK1 segment data.

Accepts a record of patient next of kin data and returns a map of NK1 segment
data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries