com.nervestaple.clinical.message-intermediate.segment.obr


->eipclj/s≠

(->eip placer-assigned filler-assigned)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.eip.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.eip.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/eip.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/eip.
sourceraw docstring

->mocclj/s≠

(->moc dollar-amount charge-code)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.moc.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.moc.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/moc.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/moc.
sourceraw docstring

->prlclj/s≠

(->prl parent-observation-id parent-result-sub-id parent-observation-result)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.prl.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.prl.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/prl.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/prl.
sourceraw docstring

->recordclj/s≠

clj
(->record set-id
          placer-order-number
          filler-order-number
          universal-service-identifier
          priority
          requested-date-time
          observation-start
          observation-end
          collection-volume
          collection-identifier
          specimen-action-code
          danger-code
          relevant-clinical-info
          specimen-received
          specimen-source
          ordering-provider
          order-callback-phone
          placer-field-1
          placer-field-2
          filler-field-1
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.record.
cljs
(->record
  set-id
  placer-order-number
  filler-order-number
  universal-service-identifier
  priority
  requested-date-time
  observation-start
  observation-end
  collection-volume
  collection-identifier
  specimen-action-code
  danger-code
  relevant-clinical-info
  specimen-received
  specimen-source
  ordering-provider
  order-callback-phone
  placer-field-1
  placer-field-2
  filler-field-1
  filler-field-2
  results-reported-status-changed
  charge-to-practice
  diagnostic-service-sect-id
  result-status
  parent-result
  quantity-timing
  result-copies-to
  parent-number
  transportation-mode
  reason-for-study
  principal-result-interpreter
  assistant-result-interpreter
  technician
  transcriptionist
  scheduled
  number-sample-containers
  transport-logistics-collected
  collector-comment
  transport-arrangement-resp
  transport-arranged
  escort-required
  planned-patient-transport-comment
  procedure-code
  procedure-code-modifier
  placer-supplemental-service-info
  filler-supplemental-service-info)

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/record.
sourceraw docstring

->spsclj/s≠

(->sps spec-source
       spec-additives
       spec-freetext
       spec-body-site
       spec-site-modifier
       spec-collection-modifier
       spec-role)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.sps.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.sps.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/sps.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.obr/sps.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

eipcljs

source

eip->fieldclj/s

(eip->field record)

Accepts one or a sequence of EIP records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of EIP records and returns a value, collection or
map of HL7 v2 data.
sourceraw docstring

field->eipclj/s

(field->eip field)

Accepts an HL7 v2 field of EIP data and returns a single record, sequence of records or nil.

Accepts an HL7 v2 field of EIP data and returns a single record, sequence of
records or nil.
sourceraw docstring

field->mocclj/s

(field->moc field)

Accepts an HL7 v2 field of MOC data and returns a single record, a sequence of records or nil.

Accepts an HL7 v2 field of MOC data and returns a single record, a sequence of
records or nil.
sourceraw docstring

field->prlclj/s

(field->prl field)

Accepts an HL7 v2 field of PRL data and returns a single record, a sequence or records or nil.

Accepts an HL7 v2 field of PRL data and returns a single record, a sequence or
records or nil.
sourceraw docstring

field->spsclj/s

(field->sps field)

Accepts and HL7 v2 field of SPS data and returns a single record, sequence of records or nil.

Accepts and HL7 v2 field of SPS data and returns a single record, sequence of
records or nil.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts an OBR segment of parsed HL7 segment data and returns an OBR record.

Accepts an OBR segment of parsed HL7 segment data and returns an OBR record.
sourceraw docstring

map->eipclj/s≠

clj
(map->eip m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.eip, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.eip, taking a map of keywords to field values.
cljs
(map->eip G__26230)

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/eip, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/eip, taking a map of keywords to field values.
sourceraw docstring

map->mocclj/s≠

clj
(map->moc m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.moc, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.moc, taking a map of keywords to field values.
cljs
(map->moc G__26251)

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/moc, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/moc, taking a map of keywords to field values.
sourceraw docstring

map->prlclj/s≠

clj
(map->prl m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.prl, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.prl, taking a map of keywords to field values.
cljs
(map->prl G__26272)

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/prl, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/prl, taking a map of keywords to field values.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.record, taking a map of keywords to field values.
cljs
(map->record G__26314)

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/record, taking a map of keywords to field values.
sourceraw docstring

map->spsclj/s≠

clj
(map->sps m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.sps, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.sps, taking a map of keywords to field values.
cljs
(map->sps G__26293)

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/sps, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.obr/sps, taking a map of keywords to field values.
sourceraw docstring

moccljs

source

moc->fieldclj/s

(moc->field moc-record)

Accepts one or a sequence of MOC records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of MOC records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

prlcljs

source

prl->fieldclj/s

(prl->field prl-record)

Accepts one or a sequence of PRL records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of PRL records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of observation request data and returns a map of OBR segment data.

Accepts a record of observation request data and returns a map of OBR segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

spscljs

source

sps->fieldclj/s

(sps->field record)

Accepts one or a sequence of SPS records and returns a value, collection or map of HL7 c2 data.

Accepts one or a sequence of SPS records and returns a value, collection or map
of HL7 c2 data.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries