(->osd sequence-flag
placer-order-number-identifier
placer-order-number-namespace
filler-order-number-identifier
filler-order-number-namespace
condition-value
max-number-repeats
placer-order-number-universal-identifier
placer-order-number-universal-type
filler-order-number-universal-identifier
filler-order-number-universal-type)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.osd.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.osd.
(->record order-control
placer-order-number
filler-order-number
placer-group-number
order-status
response-flag
timing-quantity
parent-order
transaction-date
entered-by
verified-by
ordering-provider
entered-by-location
callback-phone-number
effective-date
control-code-reason
entering-org
entering-device
action-by
advanced-beneficiary-notice-code
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.record.
(->ri repeat-pattern time-interval)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.ri.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.ri.
(->tq quantity
interval
duration
start-date
end-date
priority
condition
text
conjuniction
order-sequencing
occurence-duration
total-occurences)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.tq.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.tq.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(field->osd field)Accepts an HL7 v2 field of data and returns a single record, a sequence of records or nil.
Accepts an HL7 v2 field of data and returns a single record, a sequence of records or nil.
(field->ri field)Accepts an HL7 v2 field of data and returns a single record, a sequence of records or nil.
Accepts an HL7 v2 field of data and returns a single record, a sequence of records or nil.
(field->tq field)Accepts an HL7 v2 field of data and returns a single record, a sequence of records or nil.
Accepts an HL7 v2 field of data and returns a single record, a sequence of records or nil.
(hl7->record segment)Accepts an ORC segment of parsed HL7 data and returns an ORC record.
Accepts an ORC segment of parsed HL7 data and returns an ORC record.
(map->osd m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.osd, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.osd, taking a map of keywords to field values.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.record, taking a map of keywords to field values.
(map->ri m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.ri, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.ri, taking a map of keywords to field values.
(map->tq m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.tq, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.orc.tq, taking a map of keywords to field values.
(osd->field record)Accepts one or a sequence of OSD records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of OSD records and returns a value, collection or map of HL7 v2 data.
(record->hl7 record)Accepts a record of common order data and returns a record of ORC segment data.
Accepts a record of common order data and returns a record of ORC segment data.
(ri->field record)Accepts one or a sequence of RI records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of RI records and returns a value, collection or map of HL7 v2 data.
(tq->field record)Accepts one or a sequence of TQ records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of TQ records and returns a value, collection or map of HL7 v2 data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |