com.nervestaple.clinical.message-intermediate.segment.parser


hl7->recordclj

(hl7->record segment & [delimiters])

Accepts a segment of HL7 v2 data and an optional set of HL7 v2 delimeters (if none are provide the default set is used). Returns a segment record representing the provided segment data.

Accepts a segment of HL7 v2 data and an optional set of HL7 v2 delimeters (if
none are provide the default set is used). Returns a segment record
representing the provided segment data.
sourceraw docstring

map->recordclj

(map->record segment-id segment-map)

Accepts an HL7 segment identifier and a map of segment data, returns the appropriate segment record with that data.

Accepts an HL7 segment identifier and a map of segment data, returns the appropriate segment record
with that data.
sourceraw docstring

map-to-record-mapclj

source

record->hl7clj

(record->hl7 record)

Accepts a record of segment data and returns an HL7 v2 data segment.

Accepts a record of segment data and returns an HL7 v2 data segment.
sourceraw docstring

record-to-hl7-mapclj

Map of segment record classes to functions that will convert them to HL7 v2 segment data.

Map of segment record classes to functions that will convert them to HL7 v2
segment data.
sourceraw docstring

segment-to-parser-mapclj

Map of segment identifiers to functions that will parse HL7 v2 segment data.

Map of segment identifiers to functions that will parse HL7 v2 segment data.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries