com.nervestaple.clinical.message-intermediate.segment.pid


->dlnclj/s≠

(->dln license-number issuing-authority expiration-date)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.dln.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.dln.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pid/dln.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pid/dln.
sourceraw docstring

->recordclj/s≠

clj
(->record set-id
          patient-id
          patient-id-list
          alternate-id
          patient-name
          mother-maiden-name
          date-of-birth
          admin-gender
          patient-alias
          race
          address
          county
          phone-number-home
          phone-number-business
          primary-language
          marital-status
          religion
          patient-account-number
          social-security-number
          driver-license-number
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.record.
cljs
(->record
  set-id
  patient-id
  patient-id-list
  alternate-id
  patient-name
  mother-maiden-name
  date-of-birth
  admin-gender
  patient-alias
  race
  address
  county
  phone-number-home
  phone-number-business
  primary-language
  marital-status
  religion
  patient-account-number
  social-security-number
  driver-license-number
  mother-id
  ethnic-group
  birth-place
  multiple-birth-indicator
  birth-order
  citizenship
  veteran-military-status
  nationality
  patient-death-date-time
  patient-death-indicator
  identity-unknown-indicator
  identity-reliability-code
  last-update-date-time
  last-update-facility
  species-code
  breed-code
  strain
  production-class-code)

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pid/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pid/record.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

dlncljs

source

dln->fieldclj/s

(dln->field record)

Accepts one or a sequence of DLN records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of DLN records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

field->dlnclj/s

(field->dln field)

Accepts an HL7 v2 field of DLN data and returns a single DLN record, a sequence or records or nil.

Accepts an HL7 v2 field of DLN data and returns a single DLN record, a sequence
or records or nil.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts a PID segment of parsed HL7 segment data and returns a PID record.

Accepts a PID segment of parsed HL7 segment data and returns a PID record.
sourceraw docstring

map->dlnclj/s≠

clj
(map->dln m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.dln, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.dln, taking a map of keywords to field values.
cljs
(map->dln G__26517)

Factory function for com.nervestaple.clinical.message-intermediate.segment.pid/dln, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.pid/dln, taking a map of keywords to field values.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.record, taking a map of keywords to field values.
cljs
(map->record G__26538)

Factory function for com.nervestaple.clinical.message-intermediate.segment.pid/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.pid/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of patient identification data and returns a map of PID segment data.

Accepts a record of patient identification data and returns a map of PID
segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries