com.nervestaple.clinical.message-intermediate.segment.pv1


->dldclj/s≠

(->dld location effective-date)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/dld.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/dld.
sourceraw docstring

->fcclj/s≠

(->fc class-code effective-date)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/fc.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/fc.
sourceraw docstring

->plclj/s≠

(->pl point-of-care
      room
      bed
      facility
      location-status
      location-type
      building
      floor
      description
      identifier
      assigning-authority)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/pl.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/pl.
sourceraw docstring

->recordclj/s≠

clj
(->record set-id
          patient-class
          patient-location
          admission-type
          preadmit-number
          prior-patient-location
          attending-doctor
          referring-doctor
          consulting-doctor
          hospital-service
          temporary-location
          preadmit-test-indicator
          readmission-indicator
          admit-source
          ambulatory-status
          vip-indicator
          admitting-doctor
          patient-type
          visit-number
          financial-class
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record.
cljs
(->record
  set-id
  patient-class
  patient-location
  admission-type
  preadmit-number
  prior-patient-location
  attending-doctor
  referring-doctor
  consulting-doctor
  hospital-service
  temporary-location
  preadmit-test-indicator
  readmission-indicator
  admit-source
  ambulatory-status
  vip-indicator
  admitting-doctor
  patient-type
  visit-number
  financial-class
  charge-price-indicator
  courtesy-code
  credit-rating
  contract-code
  contract-effective-date
  contract-amount
  contract-period
  interest-code
  transfer-to-bad-debt-code
  transfer-to-bad-debt-date
  bad-debt-agency-code
  bad-debt-transfer-amount
  bad-debt-recovery-amount
  delete-account-indicator
  delete-account-date
  discharge-disposition
  discharge-location
  diet-type
  servicing-facility
  bed-status
  account-status
  pending-location
  prior-temporary-location
  admit-date-time
  discharge-date-time
  current-patient-balance
  total-charges
  total-adjustments
  total-payments
  alternate-visit-id
  visit-indicator
  other-healthcare-provider)

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/record.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

dldcljs

source

dld->fieldclj/s

(dld->field record)

Accepts on or a sequence of DLD records and returns a value, collection or map of HL7 v2 data.

Accepts on or a sequence of DLD records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

fccljs

source

fc->fieldclj/s

(fc->field record)

Accepts on or a sequence of FC records and returns a value, collection or map of HL7 v2 data.

Accepts on or a sequence of FC records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

field->dldclj/s

(field->dld field)

Accepts an HL7 v2 field of DLD data and returns a singl FC record, a sequence of records or nil.

Accepts an HL7 v2 field of DLD data and returns a singl FC record, a sequence of
records or nil.
sourceraw docstring

field->fcclj/s

(field->fc field)

Accepts an HL7 v2 field of FC data and returns a single FC record, a sequence of records or nil.

Accepts an HL7 v2 field of FC data and returns a single FC record, a sequence of
records or nil.
sourceraw docstring

field->plclj/s

(field->pl field)

Accepts an HL7 v2 field of PLN data and returns a single PLN record, a sequence of records or nil.

Accepts an HL7 v2 field of PLN data and returns a single PLN record, a sequence
of records or nil.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts a PV1 segment of parsed HL7 segment data and returns a PV1 record.

Accepts a PV1 segment of parsed HL7 segment data and returns a PV1 record.
sourceraw docstring

map->dldclj/s≠

clj
(map->dld m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld, taking a map of keywords to field values.
cljs
(map->dld G__26397)

Factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/dld, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/dld, taking a map of keywords to field values.
sourceraw docstring

map->fcclj/s≠

clj
(map->fc m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc, taking a map of keywords to field values.
cljs
(map->fc G__26376)

Factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/fc, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/fc, taking a map of keywords to field values.
sourceraw docstring

map->plclj/s≠

clj
(map->pl m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl, taking a map of keywords to field values.
cljs
(map->pl G__26355)

Factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/pl, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/pl, taking a map of keywords to field values.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record, taking a map of keywords to field values.
cljs
(map->record G__26418)

Factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.pv1/record, taking a map of keywords to field values.
sourceraw docstring

plcljs

source

pl->fieldclj/s

(pl->field record)

Accepts one or a sequence of PL records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of PL records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of patient visit data and returns a map of PV1 segment data.

Accepts a record of patient visit data and returns a map of PV1 segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries