com.nervestaple.clinical.message-intermediate.segment.rxc


->recordclj/s≠

(->record rx-component-type
          component-code
          component-amount
          component-units
          component-strength
          component-strength-units
          supplementary-code
          component-drug-strength-volume
          component-drug-strength-volume-units)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxc.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxc.record.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.rxc/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.rxc/record.
sourceraw docstring

createclj/s

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts a RXC segment of parsed HL7 segment data and returns a RXC record.

Accepts a RXC segment of parsed HL7 segment data and returns a RXC record.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxc.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxc.record, taking a map of keywords to field values.
cljs
(map->record G__26649)

Factory function for com.nervestaple.clinical.message-intermediate.segment.rxc/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.rxc/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of RXC data and returns a map of RXC segment data.

Accepts a record of RXC data and returns a map of RXC segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries