com.nervestaple.clinical.message-intermediate.segment.sft


->recordclj/s≠

(->record vendor
          release-number
          product
          identifier
          product-information
          install-date)
clj

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.sft.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.sft.record.
cljs

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.sft/record.

Positional factory function for com.nervestaple.clinical.message-intermediate.segment.sft/record.
sourceraw docstring

hl7->recordclj/s

(hl7->record segment)

Accepts a segment of parsed SFT data and returns an SFT record.

Accepts a segment of parsed SFT data and returns an SFT record.
sourceraw docstring

map->recordclj/s≠

clj
(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.sft.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.sft.record, taking a map of keywords to field values.
cljs
(map->record G__26703)

Factory function for com.nervestaple.clinical.message-intermediate.segment.sft/record, taking a map of keywords to field values.

Factory function for com.nervestaple.clinical.message-intermediate.segment.sft/record, taking a map of keywords to field values.
sourceraw docstring

recordcljs

source

record->hl7clj/s

(record->hl7 record)

Accepts a record of software data and returns a map of SFT segment data.

Accepts a record of software data and returns a map of SFT segment data.
sourceraw docstring

SEGMENT-IDclj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries