com.nervestaple.clinical.message-intermediate.utility


current-timeclj

(current-time)

Returns the current time with a time zone

Returns the current time with a time zone
sourceraw docstring

default-message-versionclj

Default HL7 Messaging specification version

Default HL7 Messaging specification version
sourceraw docstring

filter-segment-idclj

(filter-segment-id segment-id messages)

Filters incoming messages by including only those messages that have at least one segment with the matching segment identifier.

Filters incoming messages by including only those messages that have at least
one segment with the matching segment identifier.
sourceraw docstring

hl7-timestamp-formatclj

Formatter for HL7 messaging timestamps

Formatter for HL7 messaging timestamps
sourceraw docstring

parse-dateclj

(parse-date date)

Parses a date in the format YYYY-MM-DD into an HL7 date

Parses a date in the format YYYY-MM-DD into an HL7 date
sourceraw docstring

parse-phonesclj

(parse-phones phone-map email-addresses)

Parses a map of incoming phone data and a set of email addresses into a set of HL7 messaging fields

Parses a map of incoming phone data and a set of email addresses into a set of
HL7 messaging fields
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries