com.nervestaple.clinical.log.interface


add-fileclj

(add-file file-name)

Adds a new "spit" appender to the current log configuration, all log messages will be written to this file. Returns the current logging configuration.

You probably want to wrap calls to this function in a (defonce ...).

Adds a new "spit" appender to the current log configuration, all log
messages will be written to this file. Returns the current logging
configuration.

You probably want to wrap calls to this function in a `(defonce ...)`.
sourceraw docstring

debugcljmacro

(debug & args)

Logs a debug message to the log stream.

Logs a debug message to the log stream.
sourceraw docstring

errorcljmacro

(error & args)

Logs an error to the log stream.

Logs an error to the log stream.
sourceraw docstring

fatalcljmacro

(fatal & args)

Logs a fatal message to the log stream.

Logs a fatal message to the log stream.
sourceraw docstring

infocljmacro

(info & args)

Logs an informative message to the log stream.

Logs an informative message to the log stream.
sourceraw docstring

LOG-LEVELSclj

source

reportcljmacro

(report & args)

Logs a report message to the log stream.

Logs a report message to the log stream.
sourceraw docstring

set-min-levelclj

(set-min-level level)

Sets the minimum logging level and returns the current logging configuration.

Sets the minimum logging level and returns the current logging configuration.
sourceraw docstring

set-ns-log-levelclj

(set-ns-log-level namespace-to-log-levels)
(set-ns-log-level namespace log-level)

Accepts either a namespace and a key with a log level or a sequence where each item is a sequence with a namespace and a key with a log level. This data is used to set the log level for the provided namespaces.

Accepts either a namespace and a key with a log level or a sequence where each
item is a sequence with a namespace and a key with a log level. This data is
used to set the log level for the provided namespaces.
sourceraw docstring

tracecljmacro

(trace & args)

Logs a trace message to the log stream

Logs a trace message to the log stream
sourceraw docstring

warncljmacro

(warn & args)

Logs a warning to the log stream.

Logs a warning to the log stream.
sourceraw docstring

with-levelcljmacro

(with-level level & args)
source

cljdoc builds & hosts documentation for Clojure/Script libraries