(add-file file-name)Adds a new "spit" appender to the current log configuration, all log messages will be written to this file. Returns the current logging configuration.
You probably want to wrap calls to this function in a (defonce ...).
Adds a new "spit" appender to the current log configuration, all log messages will be written to this file. Returns the current logging configuration. You probably want to wrap calls to this function in a `(defonce ...)`.
(debug & args)Logs a debug message to the log stream.
Logs a debug message to the log stream.
(error & args)Logs an error to the log stream.
Logs an error to the log stream.
(fatal & args)Logs a fatal message to the log stream.
Logs a fatal message to the log stream.
(info & args)Logs an informative message to the log stream.
Logs an informative message to the log stream.
(report & args)Logs a report message to the log stream.
Logs a report message to the log stream.
(set-min-level level)Sets the minimum logging level and returns the current logging configuration.
Sets the minimum logging level and returns the current logging configuration.
(set-ns-log-level namespace-to-log-levels)(set-ns-log-level namespace log-level)Accepts either a namespace and a key with a log level or a sequence where each item is a sequence with a namespace and a key with a log level. This data is used to set the log level for the provided namespaces.
Accepts either a namespace and a key with a log level or a sequence where each item is a sequence with a namespace and a key with a log level. This data is used to set the log level for the provided namespaces.
(trace & args)Logs a trace message to the log stream
Logs a trace message to the log stream
(warn & args)Logs a warning to the log stream.
Logs a warning to the log stream.
(with-level level & args)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |