com.nervestaple.clinical.message-intermediate.demo


-mainclj

(-main & args)

Provides the main function needed to bootstrap the application.

Provides the main function needed to bootstrap the application.
sourceraw docstring

mainclj

(main & args)

Parses a sample HL& acknowledgement message into a parsed message and then parses that into an acknowledgement message.

Parses a sample HL& acknowledgement message into a parsed message and then
parses that into an acknowledgement message.
sourceraw docstring

test-ack-messageclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries