com.nervestaple.clinical.message-intermediate.interface.segment


field->tsclj

(field->ts field)

Accepts an HL7 v2 field of TS data and returns a single TS record or a sequence of records or nil.

Accepts an HL7 v2 field of TS data and returns a single TS record or a sequence
of records or nil.
sourceraw docstring

now->tsclj

(now->ts)

Returns a TS record with the current date and time.

Returns a TS record with the current date and time.
sourceraw docstring

time->tsclj

(time->ts date-time)

Accepts a zonded date time or a local data time and returns a TS record.

Accepts a zonded date time or a local data time and returns a TS record.
sourceraw docstring

ts->fieldclj

(ts->field ts-record)

Accepts one or a sequence of TS records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of TS records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries