(->record message-header message-acknowledgement error)Positional factory function for class com.nervestaple.clinical.message_intermediate.message.acknowledgement.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.message.acknowledgement.record.
(ack? message)Returns true if the provided message is an "acknowledgement" message (it has an MSH segment with a message type of "ACK").
Returns true if the provided message is an "acknowledgement" message (it has an MSH segment with a message type of "ACK").
(control-id-consistent? message)Returns true if the unique control identifier in MSH segment matches the control identifier in the MSA segment.
Returns true if the unique control identifier in MSH segment matches the control identifier in the MSA segment.
(hl7->message record)Accepts a parsed HL7 v2 acknowledgement message and returns an acknowledgement (ACK) record.
Accepts a parsed HL7 v2 acknowledgement message and returns an acknowledgement (ACK) record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.message.acknowledgement.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.message.acknowledgement.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of acknowledgement (ACK) message data and returns an ACK record.
Accepts a record of acknowledgement (ACK) message data and returns an ACK record.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |