(dump-record map-in)(dump-record map-in indent)Returns a set of strings that represent a human-readable version of the
record. If an indent value is provided it will be used to pad the front
of the returned strings.
Returns a set of strings that represent a human-readable version of the record. If an `indent` value is provided it will be used to pad the front of the returned strings.
(dump-segments segments)Returns a set of strings representing a human-readable version of the provided segments.
Returns a set of strings representing a human-readable version of the provided segments.
(dump-seq dump-record-fn seq-in)(dump-seq dump-record-fn seq-in indent)Returns a set of strings that represent a human-readable version of the
sequence of values. If an indent value is provided it will be used to pad
the front of the returned strings. If a dump-record-fn is provided, records
will be dumped using that function.
Returns a set of strings that represent a human-readable version of the sequence of values. If an `indent` value is provided it will be used to pad the front of the returned strings. If a `dump-record-fn` is provided, records will be dumped using that function.
(dump-sets sets-in)Returns a sequence of human-readable versions of the provided set data.
Returns a sequence of human-readable versions of the provided set data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |