com.nervestaple.clinical.message-intermediate.message.observation


->recordclj

(->record msh result)

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.observation.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.observation.record.
raw docstring

->resultclj

(->result pid pv1 obr obx)

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.observation.result.

Positional factory function for class com.nervestaple.clinical.message_intermediate.message.observation.result.
raw docstring

hl7->recordclj

(hl7->record parsed-message)

Accepts a parsed HL7 message and returns an observation record.

Accepts a parsed HL7 message and returns an observation record.
raw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.message.observation.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.message.observation.record, taking a map of keywords to field values.
raw docstring

map->resultclj

(map->result m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.message.observation.result, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.message.observation.result, taking a map of keywords to field values.
raw docstring

record->hl7clj

(record->hl7 record)
(record->hl7 delimiters record)

Accepts an observation record and returns a parsed HL7 message.

Accepts an observation record and returns a parsed HL7 message.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries