(->record accidate-date
accident
accident-location
auto-accident-state
accident-job-related
accident-death
accident-entered-by
accident-description
accident-brought-in-by
police-notified
accident-address
degree-of-patient-liability
accident-identifier)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.acc.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.acc.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts an ACC segment of parsed HL7 data and returns an ACC record.
Accepts an ACC segment of parsed HL7 data and returns an ACC record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.acc.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.acc.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of accident data and returns a map of ACC segment data.
Accepts a record of accident data and returns a map of ACC segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |