(->record set-id
allergen-type
allergen-description
allergy-severity
allergy-reaction
identification-date)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.al1.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.al1.record.
(hl7->record segment)Accepts an AL1 segment of parsed HL7 data and returns an AL1 record.
Accepts an AL1 segment of parsed HL7 data and returns an AL1 record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.al1.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.al1.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of patient allergy data and returns a map of AL1 segment data.
Accepts a record of patient allergy data and returns a map of AL1 segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |