(->record set-id
diagnosis-coding-method
diagnosis
diagnosis-description
diagnosis-date
diagnosis-type
major-diagnostic-category
diagnostic-related-group
drg-approval
drg-grouper-review
outlier-type
outlier-days
outlier-cost
grouper-version-and-type
diagnosis-priority
diagnosing-clinician
diagnosis-classification
confidential
attestation-date
diagnosis-identifier
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.dg1.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.dg1.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts a DG1 segment of parsed HL7 segment data and returns a DG1 record.
Accepts a DG1 segment of parsed HL7 segment data and returns a DG1 record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.dg1.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.dg1.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of diagnosis data and returns a map of DG1 segment data.
Accepts a record of diagnosis data and returns a map of DG1 segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |