com.nervestaple.clinical.message-intermediate.segment.drg


->recordclj

(->record diagnosis-related-group
          drg-assigned-date
          drg-approval-indicator
          drg-grouper-review-code
          outlier-type
          outlier-days
          outlier-cost
          drg-payor
          outlier-reimbursement
          confidential-indicator
          drg-transfer-type
          coder-name
          grouper-status
          pccl-value-code
          effective-weight
          monetary-amount
          status-patient
          grouper-software-name
          grouper-software-version
          status-financial-calculation
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record.
raw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
raw docstring

hl7->recordclj

(hl7->record segment)

Accepts a DRG segment of parsed HL7 segment data and returns a DRG record.

Accepts a DRG segment of parsed HL7 segment data and returns a DRG record.
raw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record, taking a map of keywords to field values.
raw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of diagnosis related group data and returns a map of DRG segment data.

Accepts a record of diagnosis related group data and returns a map of DRG
segment data.
raw docstring

SEGMENT-IDclj

cljdoc builds & hosts documentation for Clojure/Script libraries