(->record diagnosis-related-group
drg-assigned-date
drg-approval-indicator
drg-grouper-review-code
outlier-type
outlier-days
outlier-cost
drg-payor
outlier-reimbursement
confidential-indicator
drg-transfer-type
coder-name
grouper-status
pccl-value-code
effective-weight
monetary-amount
status-patient
grouper-software-name
grouper-software-version
status-financial-calculation
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts a DRG segment of parsed HL7 segment data and returns a DRG record.
Accepts a DRG segment of parsed HL7 segment data and returns a DRG record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.drg.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of diagnosis related group data and returns a map of DRG segment data.
Accepts a record of diagnosis related group data and returns a map of DRG segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |