com.nervestaple.clinical.message-intermediate.segment.err


->eldclj

(->eld segment-id segment-sequence field-position code-error)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.eld.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.eld.
raw docstring

->erlclj

(->erl segment-id
       segment-sequence
       field-position
       field-repetition
       component-number
       sub-component-number)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.erl.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.erl.
raw docstring

->recordclj

(->record error-code-location
          error-location
          error-code
          severity
          application-error-code
          application-error-parameter
          diagnostic-information
          user-message)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.err.record.
raw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
raw docstring

eld->fieldclj

(eld->field eld-record)

Accepts one or a sequence of ELD records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of ELD records and returns a value, collection or map
of HL7 v2 data.
raw docstring

erl->fieldclj

(erl->field erl-record)

Accepts one or a sequence of ERL records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of ERL records and returns a value, collection or map
of HL7 v2 data.
raw docstring

field->eldclj

(field->eld field)

Accepts an HL7 v2 field of ELD data and returns a single ELD record or a sequence of records or nil.

Accepts an HL7 v2 field of ELD data and returns a single ELD record or a
sequence of records or nil.
raw docstring

field->erlclj

(field->erl field)

Accepts an HL7 v2 field of ERL data and returns a single ERL record or a sequence of records or nil.

Accepts an HL7 v2 field of ERL data and returns a single ERL record or a
sequence of records or nil.
raw docstring

hl7->recordclj

(hl7->record segment)

Accepts an ERR segment of parsed HL7 data and retirns an error record.

Accepts an ERR segment of parsed HL7 data and retirns an error record.
raw docstring

map->eldclj

(map->eld m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.eld, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.eld, taking a map of keywords to field values.
raw docstring

map->erlclj

(map->erl m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.erl, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.erl, taking a map of keywords to field values.
raw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.err.record, taking a map of keywords to field values.
raw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of error (ERR) segment data and returns an ERR record.

Accepts a record of error (ERR) segment data and returns an ERR record.
raw docstring

SEGMENT-IDclj

cljdoc builds & hosts documentation for Clojure/Script libraries