(->record event-type-code
recorded-date
planned-event-date
reason-code
operator-id
event-occurred-date
event-facility)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.evn.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.evn.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(event-reason->string key-vector)Returns the matching textual string for the provided event reason code or nil if the provided value has no matches.
Returns the matching textual string for the provided event reason code or nil if the provided value has no matches.
Sequence of event reason code values (where the first key represents the "official" value) and the matching code value.
Sequence of event reason code values (where the first key represents the "official" value) and the matching code value.
(hl7->record segment)Accepts a segment of parsed HL7 segment data and returns an EVN record.
Accepts a segment of parsed HL7 segment data and returns an EVN record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.evn.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.evn.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of event type (EVN) data and returns a map of EVN segment data.
Accepts a record of event type (EVN) data and returns a map of EVN segment data.
(string->event-reason key-string)Returns the matching code value for the provided event reason textual string or nil if the provided value has no matches.
Returns the matching code value for the provided event reason textual string or nil if the provided value has no matches.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |