com.nervestaple.clinical.message-intermediate.segment.gt1


->fcclj

(->fc financial-class effective-date)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.fc.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.fc.
sourceraw docstring

->jccclj

(->jcc job-code job-class job-description)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.jcc.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.jcc.
sourceraw docstring

->recordclj

(->record set-id
          guarantor-number
          guarantor-name
          guarantor-spouse-name
          guarantor-address
          guarantor-phone-home
          guarantor-phone-business
          guarantor-birth-date
          guarantor-administrative-sex
          guarantor-type
          guarantor-relationship
          guarantor-social-security-number
          guarantor-begin-date
          guarantor-end-date
          guarantor-priority
          guarantor-employer-name
          guarantor-employer-address
          guarantor-employer-phone
          guarantor-employee-identifier
          guarantor-employment-status
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.record.
sourceraw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

fc->fieldclj

(fc->field record)

Accepts one or a sequence of FC records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of FC records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

field->fcclj

(field->fc field)

Accepts an HL7 v2 field of FCC data and returns a single FCC record, a sequence of records or nil.

Accepts an HL7 v2 field of FCC data and returns a single FCC record, a sequence
of records or nil.
sourceraw docstring

field->jccclj

(field->jcc field)

Accepts an HL7 v2 field of JCC data and returns a single JCC record, a sequence of records or nil.

Accepts an HL7 v2 field of JCC data and returns a single JCC record, a sequence
of records or nil.
sourceraw docstring

hl7->recordclj

(hl7->record segment)

Accepts a GT1 segment of parsed HL7 segment data and returns a GT1 record.

Accepts a GT1 segment of parsed HL7 segment data and returns a GT1 record.
sourceraw docstring

jcc->fieldclj

(jcc->field record)

Accepts one or a sequence of JCC records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of JCC records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

map->fcclj

(map->fc m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.fc, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.fc, taking a map of keywords to field values.
sourceraw docstring

map->jccclj

(map->jcc m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.jcc, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.jcc, taking a map of keywords to field values.
sourceraw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.gt1.record, taking a map of keywords to field values.
sourceraw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of patient guarantor data and returns a map of GT1 segment data.

Accepts a record of patient guarantor data and returns a map of GT1 segment
data.
sourceraw docstring

SEGMENT-IDclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries