(->aui authorization-number date source)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.in1/aui.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.in1/aui.
(->record set-id
plan-id
company-id
company-name
company-address
company-contact
company-telephone
group-number
group-name
group-employee-id
group-employee-name
plan-effective-date
plan-expiration-date
authorization-info
plan-type
insured-name
insured-relationship
insured-birth-date
insured-address
assignment-of-benefits
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record.
(->record
set-id
plan-id
company-id
company-name
company-address
company-contact
company-telephone
group-number
group-name
group-employee-id
group-employee-name
plan-effective-date
plan-expiration-date
authorization-info
plan-type
insured-name
insured-relationship
insured-birth-date
insured-address
assignment-of-benefits
coordination-of-benefits
coordination-of-benefits-priority
notice-admission-flag
notice-admission-date
report-eligibility-flag
report-eligibility-date
release-info-code
pre-admit-cert
verification-date
verification-person
agreement-type-code
billing-status
lifetime-reserve-days
delay-before-lr-day
company-plan-code
policy-number
policy-deductible
policy-limit-amount
policy-limit-days
room-rate-semi-private
room-rate-private
insured-employment-status
insured-administrative-gender
insured-employer-address
verification-status
prior-insurance-plan-id
coverage-type
handicap
insured-id-number)Positional factory function for com.nervestaple.clinical.message-intermediate.segment.in1/record.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.in1/record.
(aui->field record)Accepts one or a sequence of AUI records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of AUI records and returns a value, collection or map of HL7 v2 data.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(field->aui field)Accepts an HL7 v2 field of AUI data and returns a single record, a sequence of records or nil.
Accepts an HL7 v2 field of AUI data and returns a single record, a sequence of records or nil.
(hl7->record segment)Accepts a segment of parsed HL7 data and returns an IN1 record.
Accepts a segment of parsed HL7 data and returns an IN1 record.
(map->aui m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui, taking a map of keywords to field values.
(map->aui G__26116)Factory function for com.nervestaple.clinical.message-intermediate.segment.in1/aui, taking a map of keywords to field values.
Factory function for com.nervestaple.clinical.message-intermediate.segment.in1/aui, taking a map of keywords to field values.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record, taking a map of keywords to field values.
(map->record G__26137)Factory function for com.nervestaple.clinical.message-intermediate.segment.in1/record, taking a map of keywords to field values.
Factory function for com.nervestaple.clinical.message-intermediate.segment.in1/record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of insurance data and returns a map of IN1 segment data.
Accepts a record of insurance data and returns a map of IN1 segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |