com.nervestaple.clinical.message-intermediate.segment.in1


->auiclj

(->aui authorization-number date source)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui.
sourceraw docstring

->recordclj

(->record set-id
          plan-id
          company-id
          company-name
          company-address
          company-contact
          company-telephone
          group-number
          group-name
          group-employee-id
          group-employee-name
          plan-effective-date
          plan-expiration-date
          authorization-info
          plan-type
          insured-name
          insured-relationship
          insured-birth-date
          insured-address
          assignment-of-benefits
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record.
sourceraw docstring

aui->fieldclj

(aui->field record)

Accepts one or a sequence of AUI records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of AUI records and returns a value, collection or
map of HL7 v2 data.
sourceraw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

field->auiclj

(field->aui field)

Accepts an HL7 v2 field of AUI data and returns a single record, a sequence of records or nil.

Accepts an HL7 v2 field of AUI data and returns a single record, a sequence
of records or nil.
sourceraw docstring

hl7->recordclj

(hl7->record segment)

Accepts a segment of parsed HL7 data and returns an IN1 record.

Accepts a segment of parsed HL7 data and returns an IN1 record.
sourceraw docstring

map->auiclj

(map->aui m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.aui, taking a map of keywords to field values.
sourceraw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.in1.record, taking a map of keywords to field values.
sourceraw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of insurance data and returns a map of IN1 segment data.

Accepts a record of insurance data and returns a map of IN1 segment data.
sourceraw docstring

SEGMENT-IDclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries