(acknowledgement-code-by-key key-string)Returns the matching code value for the provided textual acknowledment code or nil if the value has no matches.
Returns the matching code value for the provided textual acknowledment code or nil if the value has no matches.
(acknowledgement-code-by-value key-vector)Returns the matching textual string for the provided acknowledgement code or nil if no matches are found.
Returns the matching textual string for the provided acknowledgement code or nil if no matches are found.
Sequence of acknowledgement types (where the first key represents the "official" value) and the matching code value.
Sequence of acknowledgement types (where the first key represents the "official" value) and the matching code value.
(acknowledgement-error-code-by-key key-string)Returns the matching code value for the provided textual acknowledment error code or nil if the value has no matches.
Returns the matching code value for the provided textual acknowledment error code or nil if the value has no matches.
(acknowledgement-error-code-by-value key-vector)Returns the matching textual string for the provided acknowledgement error code or nil if no matches are found.
Returns the matching textual string for the provided acknowledgement error code or nil if no matches are found.
Sequence of acknowledgement error codes (where the first key represents the "official" value) and the matching code value.
Sequence of acknowledgement error codes (where the first key represents the "official" value) and the matching code value.
(acknowledgement-type-by-key key-string)Returns the matching code value for the provided textual acknowledment type or nil if the value has no matches.
Returns the matching code value for the provided textual acknowledment type or nil if the value has no matches.
(acknowledgement-type-by-value key-vector)Returns the matching textual string for the provided acknowledgement type or nil if no matches are found.
Returns the matching textual string for the provided acknowledgement type or nil if no matches are found.
Sequence of acknowledment type data (where the first key represents the "official" value) and the matching code value.
Sequence of acknowledment type data (where the first key represents the "official" value) and the matching code value.
(address-by-key key-string)Returns the matching address type code for the provided key or nil if there are no matches.
Returns the matching address type code for the provided key or nil if there are no matches.
(address-by-value key-string)Returns the matching address value for the provided code or the value for "C" code (current) if there are no matches.
Returns the matching address value for the provided code or the value for "C" code (current) if there are no matches.
Sequence of address type keys (where the first key represents the "official" or most widely used key) and the matching code value.
Sequence of address type keys (where the first key represents the "official" or most widely used key) and the matching code value.
(convert-gender gender)Converts a textual gender value to the matching HL7 code
Converts a textual gender value to the matching HL7 code
(convert-race race)Converts a textual race value to the matching HL7 values
Converts a textual race value to the matching HL7 values
(ethnicity-by-key key-string)Returns the matching code value for the provided textual ethnicity or the code for "Unknown" of the value has no matches.
Returns the matching code value for the provided textual ethnicity or the code for "Unknown" of the value has no matches.
(ethnicity-by-value key-string)Returns the matching textual string for the provided ethnicity code or the textual value for "U" if no matches are found.
Returns the matching textual string for the provided ethnicity code or the textual value for "U" if no matches are found.
Sequence of ethnicity types (where the first key represents the "official" value) and the matching code value.
Sequence of ethnicity types (where the first key represents the "official" value) and the matching code value.
(gender-by-key key-string)Returns the matching code value for the provided textual gender value or the code for "Unknown" of the value has no matches.
Returns the matching code value for the provided textual gender value or the code for "Unknown" of the value has no matches.
(gender-by-value key-string)Returns the matching textual string for the provided gender code or the textual value for "U" if no matches are found.
Returns the matching textual string for the provided gender code or the textual value for "U" if no matches are found.
Sequence of gender types (where the first key represents the "official" value) and the matching code value.
Sequence of gender types (where the first key represents the "official" value) and the matching code value.
(key-by-value value-seq default-value value)Accepts a sequence of value maps (in the format {:keys [...] :code "XXX"}) and returns the first key value for the map that contains the provided value under its :code value. If there are no matches, the first key value for the map with default-value in its :key value is returned If there are no matches and there is no default-value, the value is returned.
Note that the value could be a string or a vector of strings: if a string is supplied and the value under the :code key is a vector then the string must match the first item in that vector; if a vector is supplied it must match the entire value under the :code key.
Accepts a sequence of value maps (in the format {:keys [...] :code "XXX"})
and returns the first key value for the map that contains the provided value
under its :code value. If there are no matches, the first key value for the
map with default-value in its :key value is returned If there are no matches
and there is no default-value, the value is returned.
Note that the value could be a string or a vector of strings: if a string is
supplied and the value under the :code key is a vector then the string must
match the first item in that vector; if a vector is supplied it must match the
entire value under the :code key.(marital-status-by-key key-string)Returns the matching code value for the provided textual marital status or the code for "Unknown" of the value has no matches.
Returns the matching code value for the provided textual marital status or the code for "Unknown" of the value has no matches.
(marital-status-by-value key-string)Returns the matching textual string for the provided marital status code or the textual value for "U" if no matches are found.
Returns the matching textual string for the provided marital status code or the textual value for "U" if no matches are found.
Sequence of martial type keys (where the first key represents the "official" value) and the matching code value.
Sequence of martial type keys (where the first key represents the "official" value) and the matching code value.
(message-structure->string key-vector)Returns the matching textual string for the provided message structure code or nil if the provided value has no matches.
Returns the matching textual string for the provided message structure code or nil if the provided value has no matches.
Sequence of message structure values (where the first key represents the "official" value) and their matching code values.
Sequence of message structure values (where the first key represents the "official" value) and their matching code values.
(patient-class-by-key key-string)Returns the matching code value for the provided textual patient class value or the code for "Unknown" of the value has no matches.
Returns the matching code value for the provided textual patient class value or the code for "Unknown" of the value has no matches.
(patient-class-by-value key-string)Returns the matching textual string for the provided patient class code or the textual value for "U" if no matches are found.
Returns the matching textual string for the provided patient class code or the textual value for "U" if no matches are found.
Sequence of patient class types (where the first key represents the "official" value) and the matching code value.
Sequence of patient class types (where the first key represents the "official" value) and the matching code value.
(processing-id-by-key key-string)Returns the matching code value for the provided textual processing ID value or nil if the value has no matches.
Returns the matching code value for the provided textual processing ID value or nil if the value has no matches.
(processing-id-by-value key-vector)Returns the matching textual string for the provided processing ID or nil if no matches are found.
Returns the matching textual string for the provided processing ID or nil if no matches are found.
Sequence of processing identifier data (where the first key represents the "official" value) and the matching code values.
Sequence of processing identifier data (where the first key represents the "official" value) and the matching code values.
(processing-mode-by-key key-string)Returns the matching code value for the provided textual processing mode value or nil if the value has no matches.
Returns the matching code value for the provided textual processing mode value or nil if the value has no matches.
(processing-mode-by-value key-vector)Returns the matching textual string for the provided processing mode or nil if no matches are found.
Returns the matching textual string for the provided processing mode or nil if no matches are found.
Sequence of processing mode data (where the first key represents the "official" value) and the matching code values.
Sequence of processing mode data (where the first key represents the "official" value) and the matching code values.
(race-by-key key-string)Returns the matching vector with the code value for the provided textual race value or the vector with the code value for "Other" of the value has no matches.
Returns the matching vector with the code value for the provided textual race value or the vector with the code value for "Other" of the value has no matches.
(race-by-value key-vector)Returns the matching textual string for the provided vector of race code data or the vector with the code value for "Other" if no matches are found.
Returns the matching textual string for the provided vector of race code data or the vector with the code value for "Other" if no matches are found.
Sequence of race types (where the first key represents the "official" value) and the matching vector of code values. Note that the code values here are not authoritative, they represent the values that appear to be the most popular.
Sequence of race types (where the first key represents the "official" value) and the matching vector of code values. Note that the code values here are not authoritative, they represent the values that appear to be the most popular.
(rxa-action-code-by-key key-string)Returns the matching code value for the provided textual RXA value or nil if the value has no matches.
Returns the matching code value for the provided textual RXA value or nil if the value has no matches.
(rxa-action-code-by-value key-vector)Returns the matching textual string for the provided RXA value or nil if no matches are found.
Returns the matching textual string for the provided RXA value or nil if no matches are found.
Sequence of RXA action code values (where the first key represents the "official" value) and the matching code values.
Sequence of RXA action code values (where the first key represents the "official" value) and the matching code values.
(rxa-completion-status-by-key key-string)Returns the matching code value for the provided textual RXA completion status or nil if the value has no matches.
Returns the matching code value for the provided textual RXA completion status or nil if the value has no matches.
(rxa-completion-status-by-value key-vector)Returns the matching textual string for the provided RXA completion status or nil if no matches are found.
Returns the matching textual string for the provided RXA completion status or nil if no matches are found.
Sequence of RXA completion status values (where the first key represents the "official" value) and the matching code values.
Sequence of RXA completion status values (where the first key represents the "official" value) and the matching code values.
(rxa-pharmacy-order-type-by-key key-string)Returns the matching code value for the provided textual RXA pharmacy order type code or nil if the value has no matches.
Returns the matching code value for the provided textual RXA pharmacy order type code or nil if the value has no matches.
(rxa-pharmacy-order-type-by-value key-vector)Returns the matching textual string for the provided RXA pharmacy order type or nil if no matches are found.
Returns the matching textual string for the provided RXA pharmacy order type or nil if no matches are found.
Sequence of RXA pharmacy order type values (where the first key represents the "official" value) and the matching code values.
Sequence of RXA pharmacy order type values (where the first key represents the "official" value) and the matching code values.
(string->message-structure key-string)Returns the matching code value for the provided message structure textual string or nil if the provided value has no matches.
Returns the matching code value for the provided message structure textual string or nil if the provided value has no matches.
(string->trigger-event key-string)Returns the matching code value for the provided trigger event textual string or nil if the provided value has no matches.
Returns the matching code value for the provided trigger event textual string or nil if the provided value has no matches.
(trigger-event->string key-vector)Returns the matching textual string for the provided trigger event code or nil if the provided value has no matches.
Returns the matching textual string for the provided trigger event code or nil if the provided value has no matches.
Sequence of trigger event values (where the first key represents the "official" value) and the matching code value.
Sequence of trigger event values (where the first key represents the "official" value) and the matching code value.
(value-for-key value-seq default-key key-string)Accepts a sequence of value maps (in the format {:keys [...] :code "XXX"}) and returns the :code value for the map that contains the provided key-string in under its :key value. If there are no matches, the :code value for the map with default-key in its :key value is returned. If there are no matches and there is no default key, the key string is returned.
Accepts a sequence of value maps (in the format {:keys [...] :code "XXX"})
and returns the :code value for the map that contains the provided key-string
in under its :key value. If there are no matches, the :code value for the map
with default-key in its :key value is returned. If there are no matches and
there is no default key, the key string is returned.(xtn-equip-by-key key-string)Returns the matching vector with the code value for the provided textual XTN equipment type code value or nil if the value has no matches.
Returns the matching vector with the code value for the provided textual XTN equipment type code value or nil if the value has no matches.
(xtn-equip-by-value key-vector)Returns the matching textual string for the provided XTN use code or nil if no matches are found.
Returns the matching textual string for the provided XTN use code or nil if no matches are found.
Sequence of telecommunication equipement type (where the first key represents the "official" value) and the matching string or vector of code values.
Sequence of telecommunication equipement type (where the first key represents the "official" value) and the matching string or vector of code values.
(xtn-use-by-key key-string)Returns the matching vector with the code value for the provided textual XTN use code value or the vector with the code value for "Other" if the value has no matches.
Returns the matching vector with the code value for the provided textual XTN use code value or the vector with the code value for "Other" if the value has no matches.
(xtn-use-by-value key-vector)Returns the matching textual string for the provided XTN use code or the code value for "Other" if no matches are found.
Returns the matching textual string for the provided XTN use code or the code value for "Other" if no matches are found.
Sequence of telecommunication use type (wher the first key represents the "official" value) and the matching string or vector of code values.
Sequence of telecommunication use type (wher the first key represents the "official" value) and the matching string or vector of code values.
(yes-no-by-key key-string)Returns the matching code value for the provided textual yes/no value or the code for "No" of the value has no matches.
Returns the matching code value for the provided textual yes/no value or the code for "No" of the value has no matches.
(yes-no-by-value key-string)Returns the matching textual string for the provided yes/no code or the textual value for "N" if no matches are found.
Returns the matching textual string for the provided yes/no code or the textual value for "N" if no matches are found.
Sequence of yes or no type keys (where the first key represents the "official" value) and the matching code value.
Sequence of yes or no type keys (where the first key represents the "official" value) and the matching code value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |