com.nervestaple.clinical.message-intermediate.segment.main


->ceclj

(->ce identifier
      text
      coding-system
      alternate-identifier
      alternate-text
      alternate-coding-system)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ce.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ce.
sourceraw docstring

->cneclj

(->cne identifier
       text
       coding-system
       alternate-identifier
       alternate-text
       alternate-coding-system
       coding-system-version
       alternate-coding-system-version
       original-text)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cne.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cne.
sourceraw docstring

->cpclj

(->cp price price-type value-from value-to range-units range-type)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cp.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cp.
sourceraw docstring

->cqclj

(->cq quantity units)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cq.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cq.
sourceraw docstring

->cweclj

(->cwe identifier
       text
       coding-system
       alternate-identifier
       alternate-text
       alternate-coding-system
       coding-system-version
       alternate-coding-system-version
       original-text)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cwe.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cwe.
sourceraw docstring

->cxclj

(->cx identifier
      check-digit
      check-scheme
      assigning-authority
      identifier-type-code
      assigning-facility
      effective-date
      expiration-date
      assigning-jurisdiction
      assigning-agency)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cx.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cx.
sourceraw docstring

->drclj

(->dr date-time-start date-time-end)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.dr.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.dr.
sourceraw docstring

->eiclj

(->ei identifier namespace-id universal-id universal-id-type)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ei.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ei.
sourceraw docstring

->fn-nameclj

(->fn-name surname
           own-surname-prefix
           own-surname
           spouse-surname-prefix
           spouse-surname)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.fn-name.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.fn-name.
sourceraw docstring

->hdclj

(->hd namespace-id universal-id universal-id-type)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hd.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hd.
sourceraw docstring

->hfnclj

(->hfn surname
       own-surname-prefix
       own-surname
       spouse-surname-prefix
       spouse-surname)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hfn.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hfn.
sourceraw docstring

->moclj

(->mo money-quantity money-denomination)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.mo.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.mo.
sourceraw docstring

->sadclj

(->sad street-address street-name dwelling-number)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.sad.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.sad.
sourceraw docstring

->tsclj

(->ts time precision)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ts.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ts.
sourceraw docstring

->xadclj

(->xad street-1
       street-2
       city
       state
       postal-code
       country
       address-type
       other-geo-designation
       county-code
       census-tract
       representation-code
       validity-range)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xad.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xad.
sourceraw docstring

->xcnclj

(->xcn id-number
       qualified-family-name
       given-name
       middle-name
       suffix
       prefix
       degree
       source-table
       authority-designator
       name-type
       xcn-check-digit
       check-scheme
       identifier-type-code
       facility
       name-representation-code
       name-representation-context
       name-validity-range
       name-assembly-order
       effective-date
       expiration-date
       &
       overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xcn.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xcn.
sourceraw docstring

->xonclj

(->xon organization-name
       organization-name-type-code
       organization-id-number
       xcn-check-digit
       check-digit-scheme
       identifier-authority
       identifier-type-code
       assigning-facility-id
       name-representation-code
       organization-identifier)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xon.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xon.
sourceraw docstring

->xpnclj

(->xpn family-name
       given-name
       further-given-name
       suffix
       prefix
       degree
       name-type-code
       name-representation-code
       name-context
       name-validity-range
       name-assembly-order)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xpn.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xpn.
sourceraw docstring

->xtnclj

(->xtn telephone-number
       use-code
       equipment-type
       email-address
       country-code
       area-code
       phone-number
       extension
       text)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xtn.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xtn.
sourceraw docstring

ce->fieldclj

(ce->field ce-record)

Accepts one or a sequence of CE records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of CE records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

ce->raceclj

(ce->race ce-race)

Returns the race keyword for the supplied CE record of race data or nil if there isn't a keyword.

Returns the race keyword for the supplied CE record of race data or nil if
there isn't a keyword.
sourceraw docstring

ce-keys-race-mapclj

Map of unique values in a race CE record to race keywords

Map of unique values in a race CE record to race keywords
sourceraw docstring

cne->fieldclj

(cne->field record)

Accepts one or a sequence of CNE records and returns a value, collection or map of HL7v2 data.

Accepts one or a sequence of CNE records and returns a value, collection or
map of HL7v2 data.
sourceraw docstring

cp->fieldclj

(cp->field record)

Accepts one or a sequence of CP records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of CP records and returns a value, collection or
map of HL7 v2 data.
sourceraw docstring

cq->fieldclj

(cq->field cq-record)

Accepts one or a sequence of CQ records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of CQ records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

cwe->fieldclj

(cwe->field record)

Accepts one or a sequence of CWE records and returns a value, collection or map of HL7v2 data.

Accepts one or a sequence of CWE records and returns a value, collection or
map of HL7v2 data.
sourceraw docstring

cx->fieldclj

(cx->field cx-record)

Accepts one or a sequence of CX record and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of CX record and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

dr->fieldclj

(dr->field dr-record)

Accepts one or a sequence of DR records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of DR records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

ei->fieldclj

(ei->field ei-record)

Accepts one or a sequence of EI records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of EI records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

field->ceclj

(field->ce field)

Accepts an HL7 v2 field of CE data and returns a single CE record or a sequence of records or nil.

Accepts an HL7 v2 field of CE data and returns a single CE record or a sequence
of records or nil.
sourceraw docstring

field->cneclj

(field->cne field)

Accepts an HL7 v2 field of CNE data and returns a single CNE record or a sequence or records or nil.

Accepts an HL7 v2 field of CNE data and returns a single CNE record or a
sequence or records or nil.
sourceraw docstring

field->cpclj

(field->cp field)

Accepts an HL7 v2 field of CP data and returns a single record, a sequence of records or nil.

Accepts an HL7 v2 field of CP data and returns a single record, a sequence
of records or nil.
sourceraw docstring

field->cqclj

(field->cq field)

Accepts an HL7 v2 field of CQ data and returns a single CQ record or a sequence of records or nil.

Accepts an HL7 v2 field of CQ data and returns a single CQ record or a sequence
of records or nil.
sourceraw docstring

field->cweclj

(field->cwe field)

Accepts an HL7 v2 field of CWE data and returns a single CWE record or a sequence or records or nil.

Accepts an HL7 v2 field of CWE data and returns a single CWE record or a
sequence or records or nil.
sourceraw docstring

field->cxclj

(field->cx field)

Accepts an HL7 v2 field of CX data and returns a single CX record or a sequence of records or nil.

Accepts an HL7 v2 field of CX data and returns a single CX record or a sequence
of records or nil.
sourceraw docstring

field->drclj

(field->dr field)

Accepts an HL7 v2 field of DR data and returns a single DR record or a sequence of records or nil.

Accepts an HL7 v2 field of DR data and returns a single DR record or a sequence
of records or nil.
sourceraw docstring

field->eiclj

(field->ei field)

Accepts an HL7 v2 field of EI data and returns a single record, a sequence of EI records or nil.

Accepts an HL7 v2 field of EI data and returns a single record, a sequence of
EI records or nil.
sourceraw docstring

field->fn-nameclj

(field->fn-name field)

Accepts an HL7 v2 field of FN data and returns a single FN record, a sequence of FN records or nil.

Accepts an HL7 v2 field of FN data and returns a single FN record, a sequence
of FN records or nil.
sourceraw docstring

field->hdclj

(field->hd field)

Accepts an HL7 v2 field of HD data and returns a single record, a sequence of HD records or nil.

Accepts an HL7 v2 field of HD data and returns a single record, a sequence of
HD records or nil.
sourceraw docstring

field->hfnclj

(field->hfn field)

Accepts an HL7 v2 field of FN data and returns a single record, a sequence of FN records or nil.

Accepts an HL7 v2 field of FN data and returns a single record, a sequence of
FN records or nil.
sourceraw docstring

field->moclj

(field->mo field)

Accepts an HL7 v2 field of MO data and returns a single record, a sequence of MO records or nil.

Accepts an HL7 v2 field of MO data and returns a single record, a sequence of
MO records or nil.
sourceraw docstring

field->sadclj

(field->sad field)

Accepts an HL7 v2 field of SAD data and returns a single record, a sequence of SAD records or nil.

Accepts an HL7 v2 field of SAD data and returns a single record, a sequence of
SAD records or nil.
sourceraw docstring

field->tsclj

(field->ts field)

Accepts an HL7 v2 field of TS data and returns a single TS record or a sequence of records or nil.

Accepts an HL7 v2 field of TS data and returns a single TS record or a sequence
of records or nil.
sourceraw docstring

field->xadclj

(field->xad field)

Accepts an HL7 v2 field of XAD data and returns a single XAD record, a sequence of XAD records or nil.

Accepts an HL7 v2 field of XAD data and returns a single XAD record, a sequence
of XAD records or nil.
sourceraw docstring

field->xcnclj

(field->xcn field)

Accepts an HL7 v2 field of XCN data and returns a single record, a sequence of XCN records or nil.

Accepts an HL7 v2 field of XCN data and returns a single record, a sequence of
XCN records or nil.
sourceraw docstring

field->xonclj

(field->xon field)

Accepts an HL7 v2 field of XON data and returns a single record, a sequence of records or nil.

Accepts an HL7 v2 field of XON data and returns a single record, a sequence
of records or nil.
sourceraw docstring

field->xpnclj

(field->xpn field)

Accepts an HL7 v2 field of XPN data and returns a single record, a sequence of XPN records or nil.

Accepts an HL7 v2 field of XPN data and returns a single record, a sequence of
XPN records or nil.
sourceraw docstring

field->xtnclj

(field->xtn field)

Accepts an HL7 v2 field of XTN data and returns a single XTN record, a sequence of XTN records or nil.

Accepts an HL7 v2 field of XTN data and returns a single XTN record, a sequence
of XTN records or nil.
sourceraw docstring

field-to-mapclj

(field-to-map field to-map-fn)

Converts a field of parsed HL7 data into a map of data by unwrapping the data in the HL7 field and then applying the result to the to-map-fn function. If the HL7 field contains repeating fields then they will be unwrapped, each applied to the to-map-fn, and a sequence of maps will be returned. If the HL7 record contains only one data item then that item will be passed in a vector to the to-map-fn.

Any field data that is not included in the record will be present on the record under the key :remainder.

Converts a field of parsed HL7 data into a map of data by unwrapping the data
in the HL7 field and then applying the result to the `to-map-fn` function. If
the HL7 field contains repeating fields then they will be unwrapped, each
applied to the `to-map-fn`, and a sequence of maps will be returned. If the HL7
record contains only one data item then that item will be passed in a vector
to the `to-map-fn`.

Any field data that is not included in the record will be present on the
record under the key `:remainder`.
sourceraw docstring

field-to-typeclj

(field-to-type field to-rec-fn to-map-fn)

Converts a field of parsed HL7 data into one or a series of maps of data with the to-map-fn and then applies each map to the to-rec-fn returning either one record or a map of records. If sub-fields or repeating fields are encountered they will be applied to the to-type-fn recursively.

Converts a field of parsed HL7 data into one or a series of maps of data with
the `to-map-fn` and then applies each map to the `to-rec-fn` returning either
one record or a map of records. If sub-fields or repeating fields are
encountered they will be applied to the `to-type-fn` recursively.
sourceraw docstring

fn-name->fieldclj

(fn-name->field fn-name-record)

Accepts one or a sequence of FN records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of FN records and returns a value, collection or
map of HL7 v2 data.
sourceraw docstring

hd->fieldclj

(hd->field hd-record)

Accepts one or a sequence of HD records and returns a value, collection or map of HL& v2 data.

Accepts one or a sequence of HD records and returns a value, collection or map
of HL& v2 data.
sourceraw docstring

hfn->fieldclj

(hfn->field hfn-record)

Accepts one or a sequence of FN records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of FN records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

map->ceclj

(map->ce m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ce, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ce, taking a map of keywords to field values.
sourceraw docstring

map->cneclj

(map->cne m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cne, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cne, taking a map of keywords to field values.
sourceraw docstring

map->cpclj

(map->cp m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cp, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cp, taking a map of keywords to field values.
sourceraw docstring

map->cqclj

(map->cq m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cq, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cq, taking a map of keywords to field values.
sourceraw docstring

map->cweclj

(map->cwe m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cwe, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cwe, taking a map of keywords to field values.
sourceraw docstring

map->cxclj

(map->cx m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cx, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cx, taking a map of keywords to field values.
sourceraw docstring

map->drclj

(map->dr m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.dr, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.dr, taking a map of keywords to field values.
sourceraw docstring

map->eiclj

(map->ei m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ei, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ei, taking a map of keywords to field values.
sourceraw docstring

map->fn-nameclj

(map->fn-name m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.fn-name, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.fn-name, taking a map of keywords to field values.
sourceraw docstring

map->hdclj

(map->hd m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hd, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hd, taking a map of keywords to field values.
sourceraw docstring

map->hfnclj

(map->hfn m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hfn, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hfn, taking a map of keywords to field values.
sourceraw docstring

map->moclj

(map->mo m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.mo, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.mo, taking a map of keywords to field values.
sourceraw docstring

map->sadclj

(map->sad m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.sad, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.sad, taking a map of keywords to field values.
sourceraw docstring

map->tsclj

(map->ts m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ts, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ts, taking a map of keywords to field values.
sourceraw docstring

map->xadclj

(map->xad m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xad, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xad, taking a map of keywords to field values.
sourceraw docstring

map->xcnclj

(map->xcn m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xcn, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xcn, taking a map of keywords to field values.
sourceraw docstring

map->xonclj

(map->xon m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xon, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xon, taking a map of keywords to field values.
sourceraw docstring

map->xpnclj

(map->xpn m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xpn, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xpn, taking a map of keywords to field values.
sourceraw docstring

map->xtnclj

(map->xtn m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xtn, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xtn, taking a map of keywords to field values.
sourceraw docstring

mo->fieldclj

(mo->field mo-record)

Accepts one or a sequence of MO records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of MO records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

now->tsclj

(now->ts)

Returns a TS record with the current date and time.

Returns a TS record with the current date and time.
sourceraw docstring

number->cqclj

(number->cq number-in)

Accepts a number and returns a CQ record.

Accepts a number and returns a CQ record.
sourceraw docstring

number->moclj

(number->mo number-in)

Accepts a number with the currency value and returns an MO record in US dollars.

Accepts a number with the currency value and returns an MO record in US dollars.
sourceraw docstring

patient-identifierclj

(patient-identifier identifier)

Returns a CX record with the provided identifier and default values.

Returns a CX record with the provided identifier and default values.
sourceraw docstring

patient-nameclj

(patient-name last first middle)

Returns an XPN record populated with the provided last, first and middle names.

Returns an XPN record populated with the provided last, first and middle
names.
sourceraw docstring

prepend-zero-moneyclj

(prepend-zero-money text)
source

race-blackclj

source

race-hispanicclj

source

race-mapclj

Map of namespaced keywords to CE records representing the appropriate race.

Map of namespaced keywords to CE records representing the appropriate race.
sourceraw docstring

race-nativeclj

source

race-otherclj

source

race-pacific-islanderclj

source

race-whiteclj

source

read-moneyclj

(read-money text)
source

sad->fieldclj

(sad->field sad-record)

Accepts one or a sequence of SAD records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of SAD records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

string->ceclj

(string->ce identifier)

Accepts a string with an identifier value and returns a CE record.

Accepts a string with an identifier value and returns a CE record.
sourceraw docstring

string->cxclj

(string->cx identifier)

Accepts a string with an identifier and returns a CX record.

Accepts a string with an identifier and returns a CX record.
sourceraw docstring

string->eiclj

(string->ei identifier)

Accepts a string with an identifier and returns an EI record.

Accepts a string with an identifier and returns an EI record.
sourceraw docstring

string->fn-nameclj

(string->fn-name family-name)

Accepts a string with a family name and returns a FN record.

Accepts a string with a family name and returns a FN record.
sourceraw docstring

string->hdclj

(string->hd namespace-id)

Accepts a string with a namespace identifier and returns an HD record.

Accepts a string with a namespace identifier and returns an HD record.
sourceraw docstring

string->hfnclj

(string->hfn family-name)

Accepts a string with a family name value and returns a HFN record.

Accepts a string with a family name value and returns a HFN record.
sourceraw docstring

string->sadclj

(string->sad street-address)

Accepts a string with an address and returns a SAD record

Accepts a string with an address and returns a SAD record
sourceraw docstring

string->xpnclj

(string->xpn last-name)
(string->xpn last-name first-name)
(string->xpn last-name first-name middle-name)

Accepts strings with last, first and middle name and returns an XPN record.

Accepts strings with last, first and middle name and returns an XPN record.
sourceraw docstring

string->xtn-emailclj

(string->xtn-email email)

Converts an email address into an XTN record.

Converts an email address into an XTN record.
sourceraw docstring

string->xtn-phoneclj

(string->xtn-phone phone)
(string->xtn-phone use-code equip-type phone)

Converts a phone number (as a string) into an XTN record. The 'use' and 'equip-type' parameters should be a textual description or a namespaced symbol from the segment. If no country code is provided then "1" is used.

Converts a phone number (as a string) into an XTN record. The 'use' and
'equip-type' parameters should be a textual description or a namespaced symbol
from the segment. If no country code is provided then "1" is used.
sourceraw docstring

time->drclj

(time->dr start end)

Accepts two Java time instances (a start and an end) and returns DR record

Accepts two Java time instances (a start and an end) and returns DR record
sourceraw docstring

time->tsclj

(time->ts date-time)

Accepts a zonded date time or a local data time and returns a TS record.

Accepts a zonded date time or a local data time and returns a TS record.
sourceraw docstring

to-field-remainderclj

(to-field-remainder to-field-fn)

Accepts a function that converts a record into a field of parsed HL7 v2 data and returns another function that converts the record, in additon any data on the :remainder key of the record to be converted is appended to the end of returned HL7 v2 data.

Accepts a function that converts a record into a field of parsed HL7 v2 data
and returns another function that converts the record, in additon any data on
the :remainder key of the record to be converted is appended to the end of
returned HL7 v2 data.
sourceraw docstring

ts->fieldclj

(ts->field ts-record)

Accepts one or a sequence of TS records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of TS records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

type-to-fieldclj

(type-to-field record to-field-fn)

Converts a record into a field of parsed HL7 data by applying the "to-field-fn" to the supplied record of data. If a sequence of records is provided then the "to-field-fn" is applied to each record and a sequence of parsed HL7 fields is returned.

Converts a record into a field of parsed HL7 data by applying the
"to-field-fn" to the supplied record of data. If a sequence of records is
provided then the "to-field-fn" is applied to each record and a sequence of
parsed HL7 fields is returned.
sourceraw docstring

xad->fieldclj

(xad->field xad-record)

Accepts an XAD record and returns a value, collection or map of HL7 v2 data.

Accepts an XAD record and returns a value, collection or map of HL7 v2
data.
sourceraw docstring

xad-birthclj

source

xad-birth-residenceclj

source

xad-businessclj

source

xad-country-originclj

source

xad-currentclj

source

xad-homeclj

source

xad-invalidclj

source

source

xad-mailingclj

source

xad-of-typeclj

(xad-of-type xad-type data-map)

Returns a XAD record of the given type, populated with the provided map of data. The street-1 value will be transformed into a SAD record.`

Returns a XAD record of the given type, populated with the provided map of
data. The `street-1` value will be transformed into a SAD record.`
sourceraw docstring

xad-permanentclj

source

xad-registryclj

source

xcn->fieldclj

(xcn->field xcn-record)

Accepts one or a sequence of XCN records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of XCN records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

xon->fieldclj

(xon->field record)

Accepts one or a sequence of XON records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of XON records and returns a value, collection or
map of HL7 v2 data.
sourceraw docstring

xpn->fieldclj

(xpn->field xpn-record)

Accepts one or a sequence of XPN records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of XPN records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

xtn->fieldclj

(xtn->field xtn-record)

Accepts one or a sequence of XTN records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of XTN records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

xtn-equip-beeperclj

source

xtn-equip-emailclj

source

xtn-equip-faxclj

source

xtn-equip-mobileclj

source

xtn-equip-modemclj

source

xtn-equip-phoneclj

source

xtn-equip-x400clj

source

xtn-use-answering-serviceclj

source

xtn-use-beeperclj

source

xtn-use-businessclj

source

xtn-use-emailclj

source

xtn-use-emergencyclj

source

xtn-use-otherclj

source

xtn-use-primaryclj

source

xtn-use-vacationclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries