(->ce identifier
text
coding-system
alternate-identifier
alternate-text
alternate-coding-system)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ce.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ce.
(->cne identifier
text
coding-system
alternate-identifier
alternate-text
alternate-coding-system
coding-system-version
alternate-coding-system-version
original-text)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cne.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cne.
(->cp price price-type value-from value-to range-units range-type)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cp.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cp.
(->cq quantity units)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cq.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cq.
(->cwe identifier
text
coding-system
alternate-identifier
alternate-text
alternate-coding-system
coding-system-version
alternate-coding-system-version
original-text)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cwe.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cwe.
(->cx identifier
check-digit
check-scheme
assigning-authority
identifier-type-code
assigning-facility
effective-date
expiration-date
assigning-jurisdiction
assigning-agency)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cx.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cx.
(->dr date-time-start date-time-end)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.dr.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.dr.
(->ei identifier namespace-id universal-id universal-id-type)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ei.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ei.
(->fn-name surname
own-surname-prefix
own-surname
spouse-surname-prefix
spouse-surname)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.fn-name.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.fn-name.
(->hd namespace-id universal-id universal-id-type)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hd.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hd.
(->hfn surname
own-surname-prefix
own-surname
spouse-surname-prefix
spouse-surname)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hfn.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hfn.
(->mo money-quantity money-denomination)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.mo.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.mo.
(->sad street-address street-name dwelling-number)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.sad.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.sad.
(->ts time precision)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ts.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ts.
(->xad street-1
street-2
city
state
postal-code
country
address-type
other-geo-designation
county-code
census-tract
representation-code
validity-range)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xad.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xad.
(->xcn id-number
qualified-family-name
given-name
middle-name
suffix
prefix
degree
source-table
authority-designator
name-type
xcn-check-digit
check-scheme
identifier-type-code
facility
name-representation-code
name-representation-context
name-validity-range
name-assembly-order
effective-date
expiration-date
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xcn.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xcn.
(->xon organization-name
organization-name-type-code
organization-id-number
xcn-check-digit
check-digit-scheme
identifier-authority
identifier-type-code
assigning-facility-id
name-representation-code
organization-identifier)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xon.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xon.
(->xpn family-name
given-name
further-given-name
suffix
prefix
degree
name-type-code
name-representation-code
name-context
name-validity-range
name-assembly-order)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xpn.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xpn.
(->xtn telephone-number
use-code
equipment-type
email-address
country-code
area-code
phone-number
extension
text)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xtn.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xtn.
(ce->field ce-record)Accepts one or a sequence of CE records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of CE records and returns a value, collection or map of HL7 v2 data.
(ce->race ce-race)Returns the race keyword for the supplied CE record of race data or nil if there isn't a keyword.
Returns the race keyword for the supplied CE record of race data or nil if there isn't a keyword.
Map of unique values in a race CE record to race keywords
Map of unique values in a race CE record to race keywords
(cne->field record)Accepts one or a sequence of CNE records and returns a value, collection or map of HL7v2 data.
Accepts one or a sequence of CNE records and returns a value, collection or map of HL7v2 data.
(cp->field record)Accepts one or a sequence of CP records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of CP records and returns a value, collection or map of HL7 v2 data.
(cq->field cq-record)Accepts one or a sequence of CQ records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of CQ records and returns a value, collection or map of HL7 v2 data.
(cwe->field record)Accepts one or a sequence of CWE records and returns a value, collection or map of HL7v2 data.
Accepts one or a sequence of CWE records and returns a value, collection or map of HL7v2 data.
(cx->field cx-record)Accepts one or a sequence of CX record and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of CX record and returns a value, collection or map of HL7 v2 data.
(dr->field dr-record)Accepts one or a sequence of DR records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of DR records and returns a value, collection or map of HL7 v2 data.
(ei->field ei-record)Accepts one or a sequence of EI records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of EI records and returns a value, collection or map of HL7 v2 data.
(field->ce field)Accepts an HL7 v2 field of CE data and returns a single CE record or a sequence of records or nil.
Accepts an HL7 v2 field of CE data and returns a single CE record or a sequence of records or nil.
(field->cne field)Accepts an HL7 v2 field of CNE data and returns a single CNE record or a sequence or records or nil.
Accepts an HL7 v2 field of CNE data and returns a single CNE record or a sequence or records or nil.
(field->cp field)Accepts an HL7 v2 field of CP data and returns a single record, a sequence of records or nil.
Accepts an HL7 v2 field of CP data and returns a single record, a sequence of records or nil.
(field->cq field)Accepts an HL7 v2 field of CQ data and returns a single CQ record or a sequence of records or nil.
Accepts an HL7 v2 field of CQ data and returns a single CQ record or a sequence of records or nil.
(field->cwe field)Accepts an HL7 v2 field of CWE data and returns a single CWE record or a sequence or records or nil.
Accepts an HL7 v2 field of CWE data and returns a single CWE record or a sequence or records or nil.
(field->cx field)Accepts an HL7 v2 field of CX data and returns a single CX record or a sequence of records or nil.
Accepts an HL7 v2 field of CX data and returns a single CX record or a sequence of records or nil.
(field->dr field)Accepts an HL7 v2 field of DR data and returns a single DR record or a sequence of records or nil.
Accepts an HL7 v2 field of DR data and returns a single DR record or a sequence of records or nil.
(field->ei field)Accepts an HL7 v2 field of EI data and returns a single record, a sequence of EI records or nil.
Accepts an HL7 v2 field of EI data and returns a single record, a sequence of EI records or nil.
(field->fn-name field)Accepts an HL7 v2 field of FN data and returns a single FN record, a sequence of FN records or nil.
Accepts an HL7 v2 field of FN data and returns a single FN record, a sequence of FN records or nil.
(field->hd field)Accepts an HL7 v2 field of HD data and returns a single record, a sequence of HD records or nil.
Accepts an HL7 v2 field of HD data and returns a single record, a sequence of HD records or nil.
(field->hfn field)Accepts an HL7 v2 field of FN data and returns a single record, a sequence of FN records or nil.
Accepts an HL7 v2 field of FN data and returns a single record, a sequence of FN records or nil.
(field->mo field)Accepts an HL7 v2 field of MO data and returns a single record, a sequence of MO records or nil.
Accepts an HL7 v2 field of MO data and returns a single record, a sequence of MO records or nil.
(field->sad field)Accepts an HL7 v2 field of SAD data and returns a single record, a sequence of SAD records or nil.
Accepts an HL7 v2 field of SAD data and returns a single record, a sequence of SAD records or nil.
(field->ts field)Accepts an HL7 v2 field of TS data and returns a single TS record or a sequence of records or nil.
Accepts an HL7 v2 field of TS data and returns a single TS record or a sequence of records or nil.
(field->xad field)Accepts an HL7 v2 field of XAD data and returns a single XAD record, a sequence of XAD records or nil.
Accepts an HL7 v2 field of XAD data and returns a single XAD record, a sequence of XAD records or nil.
(field->xcn field)Accepts an HL7 v2 field of XCN data and returns a single record, a sequence of XCN records or nil.
Accepts an HL7 v2 field of XCN data and returns a single record, a sequence of XCN records or nil.
(field->xon field)Accepts an HL7 v2 field of XON data and returns a single record, a sequence of records or nil.
Accepts an HL7 v2 field of XON data and returns a single record, a sequence of records or nil.
(field->xpn field)Accepts an HL7 v2 field of XPN data and returns a single record, a sequence of XPN records or nil.
Accepts an HL7 v2 field of XPN data and returns a single record, a sequence of XPN records or nil.
(field->xtn field)Accepts an HL7 v2 field of XTN data and returns a single XTN record, a sequence of XTN records or nil.
Accepts an HL7 v2 field of XTN data and returns a single XTN record, a sequence of XTN records or nil.
(field-to-map field to-map-fn)Converts a field of parsed HL7 data into a map of data by unwrapping the data
in the HL7 field and then applying the result to the to-map-fn function. If
the HL7 field contains repeating fields then they will be unwrapped, each
applied to the to-map-fn, and a sequence of maps will be returned. If the HL7
record contains only one data item then that item will be passed in a vector
to the to-map-fn.
Any field data that is not included in the record will be present on the
record under the key :remainder.
Converts a field of parsed HL7 data into a map of data by unwrapping the data in the HL7 field and then applying the result to the `to-map-fn` function. If the HL7 field contains repeating fields then they will be unwrapped, each applied to the `to-map-fn`, and a sequence of maps will be returned. If the HL7 record contains only one data item then that item will be passed in a vector to the `to-map-fn`. Any field data that is not included in the record will be present on the record under the key `:remainder`.
(field-to-type field to-rec-fn to-map-fn)Converts a field of parsed HL7 data into one or a series of maps of data with
the to-map-fn and then applies each map to the to-rec-fn returning either
one record or a map of records. If sub-fields or repeating fields are
encountered they will be applied to the to-type-fn recursively.
Converts a field of parsed HL7 data into one or a series of maps of data with the `to-map-fn` and then applies each map to the `to-rec-fn` returning either one record or a map of records. If sub-fields or repeating fields are encountered they will be applied to the `to-type-fn` recursively.
(fn-name->field fn-name-record)Accepts one or a sequence of FN records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of FN records and returns a value, collection or map of HL7 v2 data.
(hd->field hd-record)Accepts one or a sequence of HD records and returns a value, collection or map of HL& v2 data.
Accepts one or a sequence of HD records and returns a value, collection or map of HL& v2 data.
(hfn->field hfn-record)Accepts one or a sequence of FN records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of FN records and returns a value, collection or map of HL7 v2 data.
(map->ce m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ce, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ce, taking a map of keywords to field values.
(map->cne m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cne, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cne, taking a map of keywords to field values.
(map->cp m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cp, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cp, taking a map of keywords to field values.
(map->cq m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cq, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cq, taking a map of keywords to field values.
(map->cwe m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cwe, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cwe, taking a map of keywords to field values.
(map->cx m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cx, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.cx, taking a map of keywords to field values.
(map->dr m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.dr, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.dr, taking a map of keywords to field values.
(map->ei m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ei, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ei, taking a map of keywords to field values.
(map->fn-name m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.fn-name, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.fn-name, taking a map of keywords to field values.
(map->hd m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hd, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hd, taking a map of keywords to field values.
(map->hfn m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hfn, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.hfn, taking a map of keywords to field values.
(map->mo m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.mo, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.mo, taking a map of keywords to field values.
(map->sad m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.sad, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.sad, taking a map of keywords to field values.
(map->ts m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ts, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.ts, taking a map of keywords to field values.
(map->xad m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xad, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xad, taking a map of keywords to field values.
(map->xcn m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xcn, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xcn, taking a map of keywords to field values.
(map->xon m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xon, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xon, taking a map of keywords to field values.
(map->xpn m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xpn, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xpn, taking a map of keywords to field values.
(map->xtn m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xtn, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.main.xtn, taking a map of keywords to field values.
(mo->field mo-record)Accepts one or a sequence of MO records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of MO records and returns a value, collection or map of HL7 v2 data.
(now->ts)Returns a TS record with the current date and time.
Returns a TS record with the current date and time.
(number->cq number-in)Accepts a number and returns a CQ record.
Accepts a number and returns a CQ record.
(number->mo number-in)Accepts a number with the currency value and returns an MO record in US dollars.
Accepts a number with the currency value and returns an MO record in US dollars.
(patient-identifier identifier)Returns a CX record with the provided identifier and default values.
Returns a CX record with the provided identifier and default values.
(patient-name last first middle)Returns an XPN record populated with the provided last, first and middle names.
Returns an XPN record populated with the provided last, first and middle names.
(prepend-zero-money text)Map of namespaced keywords to CE records representing the appropriate race.
Map of namespaced keywords to CE records representing the appropriate race.
(read-money text)(sad->field sad-record)Accepts one or a sequence of SAD records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of SAD records and returns a value, collection or map of HL7 v2 data.
(string->ce identifier)Accepts a string with an identifier value and returns a CE record.
Accepts a string with an identifier value and returns a CE record.
(string->cx identifier)Accepts a string with an identifier and returns a CX record.
Accepts a string with an identifier and returns a CX record.
(string->ei identifier)Accepts a string with an identifier and returns an EI record.
Accepts a string with an identifier and returns an EI record.
(string->fn-name family-name)Accepts a string with a family name and returns a FN record.
Accepts a string with a family name and returns a FN record.
(string->hd namespace-id)Accepts a string with a namespace identifier and returns an HD record.
Accepts a string with a namespace identifier and returns an HD record.
(string->hfn family-name)Accepts a string with a family name value and returns a HFN record.
Accepts a string with a family name value and returns a HFN record.
(string->sad street-address)Accepts a string with an address and returns a SAD record
Accepts a string with an address and returns a SAD record
(string->xpn last-name)(string->xpn last-name first-name)(string->xpn last-name first-name middle-name)Accepts strings with last, first and middle name and returns an XPN record.
Accepts strings with last, first and middle name and returns an XPN record.
(string->xtn-email email)Converts an email address into an XTN record.
Converts an email address into an XTN record.
(string->xtn-phone phone)(string->xtn-phone use-code equip-type phone)Converts a phone number (as a string) into an XTN record. The 'use' and 'equip-type' parameters should be a textual description or a namespaced symbol from the segment. If no country code is provided then "1" is used.
Converts a phone number (as a string) into an XTN record. The 'use' and 'equip-type' parameters should be a textual description or a namespaced symbol from the segment. If no country code is provided then "1" is used.
(time->dr start end)Accepts two Java time instances (a start and an end) and returns DR record
Accepts two Java time instances (a start and an end) and returns DR record
(time->ts date-time)Accepts a zonded date time or a local data time and returns a TS record.
Accepts a zonded date time or a local data time and returns a TS record.
(to-field-remainder to-field-fn)Accepts a function that converts a record into a field of parsed HL7 v2 data and returns another function that converts the record, in additon any data on the :remainder key of the record to be converted is appended to the end of returned HL7 v2 data.
Accepts a function that converts a record into a field of parsed HL7 v2 data and returns another function that converts the record, in additon any data on the :remainder key of the record to be converted is appended to the end of returned HL7 v2 data.
(ts->field ts-record)Accepts one or a sequence of TS records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of TS records and returns a value, collection or map of HL7 v2 data.
(type-to-field record to-field-fn)Converts a record into a field of parsed HL7 data by applying the "to-field-fn" to the supplied record of data. If a sequence of records is provided then the "to-field-fn" is applied to each record and a sequence of parsed HL7 fields is returned.
Converts a record into a field of parsed HL7 data by applying the "to-field-fn" to the supplied record of data. If a sequence of records is provided then the "to-field-fn" is applied to each record and a sequence of parsed HL7 fields is returned.
(xad->field xad-record)Accepts an XAD record and returns a value, collection or map of HL7 v2 data.
Accepts an XAD record and returns a value, collection or map of HL7 v2 data.
(xad-of-type xad-type data-map)Returns a XAD record of the given type, populated with the provided map of
data. The street-1 value will be transformed into a SAD record.`
Returns a XAD record of the given type, populated with the provided map of data. The `street-1` value will be transformed into a SAD record.`
(xcn->field xcn-record)Accepts one or a sequence of XCN records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of XCN records and returns a value, collection or map of HL7 v2 data.
(xon->field record)Accepts one or a sequence of XON records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of XON records and returns a value, collection or map of HL7 v2 data.
(xpn->field xpn-record)Accepts one or a sequence of XPN records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of XPN records and returns a value, collection or map of HL7 v2 data.
(xtn->field xtn-record)Accepts one or a sequence of XTN records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of XTN records and returns a value, collection or map of HL7 v2 data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |