(->record prior-patient-id-list
prior-alternate-id
prior-patient-account-number
prior-patient-id
prior-visit-number
prior-alternate-visit-id
prior-patient-name)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.mrg.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.mrg.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts an MRG segment of parsed HL7 segment data and returns an MRG record.
Accepts an MRG segment of parsed HL7 segment data and returns an MRG record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.mrg.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.mrg.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of merge data and returns a map of MRG segment data.
Accepts a record of merge data and returns a map of MRG segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |