(->record acknowledgement-code
message-control-id
message
expected-sequence-number
delayed-acknowledgement-type
error-condition
message-waiting-number
message-waiting-priority)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msa.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msa.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accpets an MSA segment of parsed HL7 data and returns a message acknowledgement record.
Accpets an MSA segment of parsed HL7 data and returns a message acknowledgement record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.msa.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.msa.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of message acknowledgement (MSA) segment data and returns an MSA record.
Accepts a record of message acknowledgement (MSA) segment data and returns an MSA record.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |