com.nervestaple.clinical.message-intermediate.segment.msh


->msgclj

(->msg msg-code msg-trigger msg-structure)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg.
sourceraw docstring

->ptclj

(->pt processing-id processing-mode)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt.
sourceraw docstring

->recordclj

(->record delimiters
          sending-application
          sending-facility
          receiving-application
          receiving-facility
          message-created
          security
          message-type
          message-control-id
          message-processing-id
          message-version-id
          sequence-number
          continuation-pointer
          accept-acknowledgement-type
          application-acknowledgement-type
          country-code
          character-set
          principal-language
          alternate-character-set
          message-profile-indicator
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record.
sourceraw docstring

->vidclj

(->vid version-id international-code international-version-id)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid.
sourceraw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

default-delimitersclj

Map with our default set of delimiters

Map with our default set of delimiters
sourceraw docstring

field->msgclj

(field->msg field)

Accepts an HL7 v2 field of MSG data and returns a single MSG record or a sequence of records or nil.

Accepts an HL7 v2 field of MSG data and returns a single MSG record or a
sequence of records or nil.
sourceraw docstring

field->ptclj

(field->pt field)

Accepts an HL7 v2 field of PT data and returns a single PT record or a sequence of records or nil.

Accepts an HL7 v2 field of PT data and returns a single PT record or a sequence
of records or nil.
sourceraw docstring

field->vidclj

(field->vid field)

Accepts an HL7 v2 field of VID data and returns a single VID record or a sequence of records or nil.

Accepts an HL7 v2 field of VID data and returns a single VID record or a
sequence of records or nil.
sourceraw docstring

hl7->recordclj

(hl7->record segment & [delimiters])

Accepts an MSH segment of parsed HL7 data and retirns a record.

Accepts an MSH segment of parsed HL7 data and retirns a record.
sourceraw docstring

map->msgclj

(map->msg m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg, taking a map of keywords to field values.
sourceraw docstring

map->ptclj

(map->pt m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt, taking a map of keywords to field values.
sourceraw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record, taking a map of keywords to field values.
sourceraw docstring

map->vidclj

(map->vid m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid, taking a map of keywords to field values.
sourceraw docstring

msg->fieldclj

(msg->field msg-record)

Accepts one or a sequence of MSG records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of MSG records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

pt->fieldclj

(pt->field pt-record)

Accepts one or a sequence of PT records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of PT records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

pt-debugclj

source

pt-productionclj

source

pt-testclj

source

record->hl7clj

(record->hl7 record)

Accepts a record of message header (MSH) segment data and returns a map of MSH segment data.

Accepts a record of message header (MSH) segment data and returns a map of MSH
segment data.
sourceraw docstring

SEGMENT-IDclj

source

string->vidclj

(string->vid version-id)

Accepts a string with version identifier and returns a VID record.

Accepts a string with version identifier and returns a VID record.
sourceraw docstring

vid->fieldclj

(vid->field vid-record)

Accepts one or a sequence of VID records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of VID records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries