(->msg msg-code msg-trigger msg-structure)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg.
(->pt processing-id processing-mode)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt.
(->record delimiters
sending-application
sending-facility
receiving-application
receiving-facility
message-created
security
message-type
message-control-id
message-processing-id
message-version-id
sequence-number
continuation-pointer
accept-acknowledgement-type
application-acknowledgement-type
country-code
character-set
principal-language
alternate-character-set
message-profile-indicator
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record.
(->vid version-id international-code international-version-id)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
Map with our default set of delimiters
Map with our default set of delimiters
(field->msg field)Accepts an HL7 v2 field of MSG data and returns a single MSG record or a sequence of records or nil.
Accepts an HL7 v2 field of MSG data and returns a single MSG record or a sequence of records or nil.
(field->pt field)Accepts an HL7 v2 field of PT data and returns a single PT record or a sequence of records or nil.
Accepts an HL7 v2 field of PT data and returns a single PT record or a sequence of records or nil.
(field->vid field)Accepts an HL7 v2 field of VID data and returns a single VID record or a sequence of records or nil.
Accepts an HL7 v2 field of VID data and returns a single VID record or a sequence of records or nil.
(hl7->record segment & [delimiters])Accepts an MSH segment of parsed HL7 data and retirns a record.
Accepts an MSH segment of parsed HL7 data and retirns a record.
(map->msg m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.msg, taking a map of keywords to field values.
(map->pt m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.pt, taking a map of keywords to field values.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.record, taking a map of keywords to field values.
(map->vid m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.msh.vid, taking a map of keywords to field values.
(msg->field msg-record)Accepts one or a sequence of MSG records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of MSG records and returns a value, collection or map of HL7 v2 data.
(pt->field pt-record)Accepts one or a sequence of PT records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of PT records and returns a value, collection or map of HL7 v2 data.
(record->hl7 record)Accepts a record of message header (MSH) segment data and returns a map of MSH segment data.
Accepts a record of message header (MSH) segment data and returns a map of MSH segment data.
(string->vid version-id)Accepts a string with version identifier and returns a VID record.
Accepts a string with version identifier and returns a VID record.
(vid->field vid-record)Accepts one or a sequence of VID records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of VID records and returns a value, collection or map of HL7 v2 data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |