(->jcc job-code job-class)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc.
(->record set-id
associated-party-name
relationship
address
phone-number
business-phone-number
contact-role
start-date
end-date
associated-party-job-title
associated-party-job-code
associated-party-employee-number
associated-party-organization-name
martial-status
administrative-gender
birth-date
living-dependency
ambulatory-status
citizenship
primary-language
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(field->jcc field)Accepts an HL7 v2 field of JCC data and returns a single JCC record, a sequence of records or nil.
Accepts an HL7 v2 field of JCC data and returns a single JCC record, a sequence of records or nil.
(hl7->record segment)Accepts an NK1 segment of parsed HL7 segment data and returns an NK1 record.
Accepts an NK1 segment of parsed HL7 segment data and returns an NK1 record.
(jcc->field record)Accepts one or a sequence of JCC records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of JCC records and returns a value, collection or map of HL7 v2 data.
(map->jcc m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc, taking a map of keywords to field values.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of patient next of kin data and returns a map of NK1 segment data.
Accepts a record of patient next of kin data and returns a map of NK1 segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |