com.nervestaple.clinical.message-intermediate.segment.nk1


->jccclj

(->jcc job-code job-class)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc.
raw docstring

->recordclj

(->record set-id
          associated-party-name
          relationship
          address
          phone-number
          business-phone-number
          contact-role
          start-date
          end-date
          associated-party-job-title
          associated-party-job-code
          associated-party-employee-number
          associated-party-organization-name
          martial-status
          administrative-gender
          birth-date
          living-dependency
          ambulatory-status
          citizenship
          primary-language
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record.
raw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
raw docstring

field->jccclj

(field->jcc field)

Accepts an HL7 v2 field of JCC data and returns a single JCC record, a sequence of records or nil.

Accepts an HL7 v2 field of JCC data and returns a single JCC record, a
sequence of records or nil.
raw docstring

hl7->recordclj

(hl7->record segment)

Accepts an NK1 segment of parsed HL7 segment data and returns an NK1 record.

Accepts an NK1 segment of parsed HL7 segment data and returns an NK1 record.
raw docstring

jcc->fieldclj

(jcc->field record)

Accepts one or a sequence of JCC records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of JCC records and returns a value, collection or
map of HL7 v2 data.
raw docstring

map->jccclj

(map->jcc m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.jcc, taking a map of keywords to field values.
raw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.nk1.record, taking a map of keywords to field values.
raw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of patient next of kin data and returns a map of NK1 segment data.

Accepts a record of patient next of kin data and returns a map of NK1 segment
data.
raw docstring

SEGMENT-IDclj

cljdoc builds & hosts documentation for Clojure/Script libraries