(->record set-id comment-source comment comment-type)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nte.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.nte.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts an NTE segment of parsed HL7 data and returns an NTE record.
Accepts an NTE segment of parsed HL7 data and returns an NTE record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.nte.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.nte.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of note (NTE) segment data and returns a parsed HL7 segment.
Accepts a record of note (NTE) segment data and returns a parsed HL7 segment.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |