(->eip placer-assigned filler-assigned)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.eip.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.eip.
(->moc dollar-amount charge-code)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.moc.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.moc.
(->prl parent-observation-id parent-result-sub-id parent-observation-result)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.prl.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.prl.
(->record set-id
placer-order-number
filler-order-number
universal-service-identifier
priority
requested-date-time
observation-start
observation-end
collection-volume
collection-identifier
specimen-action-code
danger-code
relevant-clinical-info
specimen-received
specimen-source
ordering-provider
order-callback-phone
placer-field-1
placer-field-2
filler-field-1
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.record.
(->sps spec-source
spec-additives
spec-freetext
spec-body-site
spec-site-modifier
spec-collection-modifier
spec-role)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.sps.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.sps.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(eip->field record)Accepts one or a sequence of EIP records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of EIP records and returns a value, collection or map of HL7 v2 data.
(field->eip field)Accepts an HL7 v2 field of EIP data and returns a single record, sequence of records or nil.
Accepts an HL7 v2 field of EIP data and returns a single record, sequence of records or nil.
(field->moc field)Accepts an HL7 v2 field of MOC data and returns a single record, a sequence of records or nil.
Accepts an HL7 v2 field of MOC data and returns a single record, a sequence of records or nil.
(field->prl field)Accepts an HL7 v2 field of PRL data and returns a single record, a sequence or records or nil.
Accepts an HL7 v2 field of PRL data and returns a single record, a sequence or records or nil.
(field->sps field)Accepts and HL7 v2 field of SPS data and returns a single record, sequence of records or nil.
Accepts and HL7 v2 field of SPS data and returns a single record, sequence of records or nil.
(hl7->record segment)Accepts an OBR segment of parsed HL7 segment data and returns an OBR record.
Accepts an OBR segment of parsed HL7 segment data and returns an OBR record.
(map->eip m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.eip, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.eip, taking a map of keywords to field values.
(map->moc m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.moc, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.moc, taking a map of keywords to field values.
(map->prl m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.prl, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.prl, taking a map of keywords to field values.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.record, taking a map of keywords to field values.
(map->sps m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.sps, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.obr.sps, taking a map of keywords to field values.
(moc->field moc-record)Accepts one or a sequence of MOC records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of MOC records and returns a value, collection or map of HL7 v2 data.
(prl->field prl-record)Accepts one or a sequence of PRL records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of PRL records and returns a value, collection or map of HL7 v2 data.
(record->hl7 record)Accepts a record of observation request data and returns a map of OBR segment data.
Accepts a record of observation request data and returns a map of OBR segment data.
(sps->field record)Accepts one or a sequence of SPS records and returns a value, collection or map of HL7 c2 data.
Accepts one or a sequence of SPS records and returns a value, collection or map of HL7 c2 data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |