com.nervestaple.clinical.message-intermediate.segment.obx


->recordclj

(->record set-id
          value-type
          observation-identifier
          observation-sub-identifier
          observation-value
          units
          references-range
          abnormal-flags
          probability
          nature-of-abnormal-test
          observation-result-status
          reference-range-effective-date
          user-defined-access-checks
          observation-date
          producer-identifier
          responsible-observer
          observation-method
          equipment-instance-identifier
          analysis-date)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obx.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.obx.record.
sourceraw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

hl7->recordclj

(hl7->record segment)

Accepts an OBX segment of parsed HL7 segment data and returns an OBX record.

Accepts an OBX segment of parsed HL7 segment data and returns an OBX record.
sourceraw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obx.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.obx.record, taking a map of keywords to field values.
sourceraw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of observation/result data and returns map of OBR segment data.

Accepts a record of observation/result data and returns map of OBR segment data.
sourceraw docstring

SEGMENT-IDclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries