(hl7->record segment & [delimiters])Accepts a segment of HL7 v2 data and an optional set of HL7 v2 delimeters (if none are provide the default set is used). Returns a segment record representing the provided segment data.
Accepts a segment of HL7 v2 data and an optional set of HL7 v2 delimeters (if none are provide the default set is used). Returns a segment record representing the provided segment data.
(map->record segment-id segment-map)Accepts an HL7 segment identifier and a map of segment data, returns the appropriate segment record with that data.
Accepts an HL7 segment identifier and a map of segment data, returns the appropriate segment record with that data.
(record->hl7 record)Accepts a record of segment data and returns an HL7 v2 data segment.
Accepts a record of segment data and returns an HL7 v2 data segment.
Map of segment record classes to functions that will convert them to HL7 v2 segment data.
Map of segment record classes to functions that will convert them to HL7 v2 segment data.
Map of segment identifiers to functions that will parse HL7 v2 segment data.
Map of segment identifiers to functions that will parse HL7 v2 segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |