(->record living-dependency
living-arrangement
primary-facility
primary-care-provider
student-indicator
handicap
living-will-code
organ-donor-code
separate-bill
duplicate-patient
publicity-code
protection-indicator
protection-indicator-effective
place-of-worship
advance-directive-code
immunization-registry-status
immunization-registry-status-effective
publicity-code-effective
military-branch
military-rank
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pd1.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pd1.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts a PD1 segment of parsed HL7 v2 data and returns a PD1 record.
Accepts a PD1 segment of parsed HL7 v2 data and returns a PD1 record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.pd1.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.pd1.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of patient additional demographic data and returns a map of PD1 segment data.
Accepts a record of patient additional demographic data and returns a map of PD1 segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |