com.nervestaple.clinical.message-intermediate.segment.pid


->dlnclj

(->dln license-number issuing-authority expiration-date)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.dln.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.dln.
sourceraw docstring

->recordclj

(->record set-id
          patient-id
          patient-id-list
          alternate-id
          patient-name
          mother-maiden-name
          date-of-birth
          admin-gender
          patient-alias
          race
          address
          county
          phone-number-home
          phone-number-business
          primary-language
          marital-status
          religion
          patient-account-number
          social-security-number
          driver-license-number
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.record.
sourceraw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

dln->fieldclj

(dln->field record)

Accepts one or a sequence of DLN records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of DLN records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

field->dlnclj

(field->dln field)

Accepts an HL7 v2 field of DLN data and returns a single DLN record, a sequence or records or nil.

Accepts an HL7 v2 field of DLN data and returns a single DLN record, a sequence
or records or nil.
sourceraw docstring

hl7->recordclj

(hl7->record segment)

Accepts a PID segment of parsed HL7 segment data and returns a PID record.

Accepts a PID segment of parsed HL7 segment data and returns a PID record.
sourceraw docstring

map->dlnclj

(map->dln m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.dln, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.dln, taking a map of keywords to field values.
sourceraw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pid.record, taking a map of keywords to field values.
sourceraw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of patient identification data and returns a map of PID segment data.

Accepts a record of patient identification data and returns a map of PID
segment data.
sourceraw docstring

SEGMENT-IDclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries