com.nervestaple.clinical.message-intermediate.segment.pv1


->dldclj

(->dld location effective-date)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld.
sourceraw docstring

->fcclj

(->fc class-code effective-date)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc.
sourceraw docstring

->plclj

(->pl point-of-care
      room
      bed
      facility
      location-status
      location-type
      building
      floor
      description
      identifier
      assigning-authority)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl.
sourceraw docstring

->recordclj

(->record set-id
          patient-class
          patient-location
          admission-type
          preadmit-number
          prior-patient-location
          attending-doctor
          referring-doctor
          consulting-doctor
          hospital-service
          temporary-location
          preadmit-test-indicator
          readmission-indicator
          admit-source
          ambulatory-status
          vip-indicator
          admitting-doctor
          patient-type
          visit-number
          financial-class
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record.
sourceraw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

dld->fieldclj

(dld->field record)

Accepts on or a sequence of DLD records and returns a value, collection or map of HL7 v2 data.

Accepts on or a sequence of DLD records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

fc->fieldclj

(fc->field record)

Accepts on or a sequence of FC records and returns a value, collection or map of HL7 v2 data.

Accepts on or a sequence of FC records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

field->dldclj

(field->dld field)

Accepts an HL7 v2 field of DLD data and returns a singl FC record, a sequence of records or nil.

Accepts an HL7 v2 field of DLD data and returns a singl FC record, a sequence of
records or nil.
sourceraw docstring

field->fcclj

(field->fc field)

Accepts an HL7 v2 field of FC data and returns a single FC record, a sequence of records or nil.

Accepts an HL7 v2 field of FC data and returns a single FC record, a sequence of
records or nil.
sourceraw docstring

field->plclj

(field->pl field)

Accepts an HL7 v2 field of PLN data and returns a single PLN record, a sequence of records or nil.

Accepts an HL7 v2 field of PLN data and returns a single PLN record, a sequence
of records or nil.
sourceraw docstring

hl7->recordclj

(hl7->record segment)

Accepts a PV1 segment of parsed HL7 segment data and returns a PV1 record.

Accepts a PV1 segment of parsed HL7 segment data and returns a PV1 record.
sourceraw docstring

map->dldclj

(map->dld m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld, taking a map of keywords to field values.
sourceraw docstring

map->fcclj

(map->fc m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc, taking a map of keywords to field values.
sourceraw docstring

map->plclj

(map->pl m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl, taking a map of keywords to field values.
sourceraw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record, taking a map of keywords to field values.
sourceraw docstring

pl->fieldclj

(pl->field record)

Accepts one or a sequence of PL records and returns a value, collection or map of HL7 v2 data.

Accepts one or a sequence of PL records and returns a value, collection or map
of HL7 v2 data.
sourceraw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of patient visit data and returns a map of PV1 segment data.

Accepts a record of patient visit data and returns a map of PV1 segment data.
sourceraw docstring

SEGMENT-IDclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries