(->dld location effective-date)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld.
(->fc class-code effective-date)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc.
(->pl point-of-care
room
bed
facility
location-status
location-type
building
floor
description
identifier
assigning-authority)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl.
(->record set-id
patient-class
patient-location
admission-type
preadmit-number
prior-patient-location
attending-doctor
referring-doctor
consulting-doctor
hospital-service
temporary-location
preadmit-test-indicator
readmission-indicator
admit-source
ambulatory-status
vip-indicator
admitting-doctor
patient-type
visit-number
financial-class
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(dld->field record)Accepts on or a sequence of DLD records and returns a value, collection or map of HL7 v2 data.
Accepts on or a sequence of DLD records and returns a value, collection or map of HL7 v2 data.
(fc->field record)Accepts on or a sequence of FC records and returns a value, collection or map of HL7 v2 data.
Accepts on or a sequence of FC records and returns a value, collection or map of HL7 v2 data.
(field->dld field)Accepts an HL7 v2 field of DLD data and returns a singl FC record, a sequence of records or nil.
Accepts an HL7 v2 field of DLD data and returns a singl FC record, a sequence of records or nil.
(field->fc field)Accepts an HL7 v2 field of FC data and returns a single FC record, a sequence of records or nil.
Accepts an HL7 v2 field of FC data and returns a single FC record, a sequence of records or nil.
(field->pl field)Accepts an HL7 v2 field of PLN data and returns a single PLN record, a sequence of records or nil.
Accepts an HL7 v2 field of PLN data and returns a single PLN record, a sequence of records or nil.
(hl7->record segment)Accepts a PV1 segment of parsed HL7 segment data and returns a PV1 record.
Accepts a PV1 segment of parsed HL7 segment data and returns a PV1 record.
(map->dld m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.dld, taking a map of keywords to field values.
(map->fc m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.fc, taking a map of keywords to field values.
(map->pl m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.pl, taking a map of keywords to field values.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv1.record, taking a map of keywords to field values.
(pl->field record)Accepts one or a sequence of PL records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of PL records and returns a value, collection or map of HL7 v2 data.
(record->hl7 record)Accepts a record of patient visit data and returns a map of PV1 segment data.
Accepts a record of patient visit data and returns a map of PV1 segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |