(->record prior-pending-location
accomodation
admit-reason
transfer-reason
patient-valuables
patient-valuables-location
visit-user
expected-admit-date
expected-discharge-date
estimated-length-inpatient-stay
estimated-length-outpatient-stay
visit-description
referral-source
previous-service-date
employment-illness-related
purge-status
purge-status-date
special-program
retention
expected-number-insurance-plans
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv2.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv2.record.
(->record
prior-pending-location
accomodation
admit-reason
transfer-reason
patient-valuables
patient-valuables-location
visit-user
expected-admit-date
expected-discharge-date
estimated-length-inpatient-stay
estimated-length-outpatient-stay
visit-description
referral-source
previous-service-date
employment-illness-related
purge-status
purge-status-date
special-program
retention
expected-number-insurance-plans
visit-publicity
clinic-organization
patient-status
visit-priority
previous-treatment-date
expected-discharge-disposition
signature-on-file-date
first-similar-illness-date
patient-charge-adjustment
recurring-service
billing-media
expected-surgery-date
military-partnership
military-non-availability
newborn-baby
mode-of-arrival
recreational-drug-use
admission-level-of-care
precaution
patient-condition
living-will
organ-donor
advance-directive
patient-status-effective-date
expected-loa-return-date
expected-pre-admission-testing-date
notify-clergy
advance-directive-last-verified-date)Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv2/record.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.pv2/record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts a segment of parsed HL7 segment data and returns a PV2 record.
Accepts a segment of parsed HL7 segment data and returns a PV2 record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv2.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv2.record, taking a map of keywords to field values.
(map->record G__26574)Factory function for com.nervestaple.clinical.message-intermediate.segment.pv2/record, taking a map of keywords to field values.
Factory function for com.nervestaple.clinical.message-intermediate.segment.pv2/record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of patient visit 2 (PV2) data and returns a map of PV@ segment data.
Accepts a record of patient visit 2 (PV2) data and returns a map of PV@ segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |