(->record prior-pending-location
accomodation
admit-reason
transfer-reason
patient-valuables
patient-valuables-location
visit-user
expected-admit-date
expected-discharge-date
estimated-length-inpatient-stay
estimated-length-outpatient-stay
visit-description
referral-source
previous-service-date
employment-illness-related
purge-status
purge-status-date
special-program
retention
expected-number-insurance-plans
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv2.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.pv2.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts a segment of parsed HL7 segment data and returns a PV2 record.
Accepts a segment of parsed HL7 segment data and returns a PV2 record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv2.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.pv2.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of patient visit 2 (PV2) data and returns a map of PV@ segment data.
Accepts a record of patient visit 2 (PV2) data and returns a map of PV@ segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |