(->record role-instance-id
action-code
role
role-person
role-begin-date
role-end-date
role-duration
role-action-reason
role-provider-type
organization-unit-type
role-address
role-telephone)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rol.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rol.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts a ROL segment of parsed HL7 segment data and returns a ROL record.
Accepts a ROL segment of parsed HL7 segment data and returns a ROL record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.rol.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.rol.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of role data and returns a map of ROL segment data.
Accepts a record of role data and returns a map of ROL segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |