(->la2 point-of-care
room
bed
facility
location-status
location-type
building
floor
street-address
other-designation
city
state
postal-code
country
address-type
other-geographic-designation)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxa.la2.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxa.la2.
(->record rxg-id-counter
admin-id-counter
admin-start
admin-end
administered-code
administered-amount
administered-units
administered-dosage-form
admin-notes
admin-provider
admin-location
administered-time-unit
administered-strength
administered-strength-unit
lot-number
lot-expiration
lot-manufacturer
treatment-refusal-reason
indication
completion-status
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxa.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxa.record.
(action-code->string code-key)Returns the textual string for the provided RXA action code, or nil if no match was found.
Returns the textual string for the provided RXA action code, or nil if no match was found.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(field->la2 field)Accepts an HL7 v2 field of data and returns a single record, a sequence of records or nil.
Accepts an HL7 v2 field of data and returns a single record, a sequence of records or nil.
(hl7->record segment)Accepts an RXA segment of parsed HL7 v2 data and returns an RXA record.
Accepts an RXA segment of parsed HL7 v2 data and returns an RXA record.
(la2->field record)Accepts one or a sequence of LA2 records and returns a value, collection or map of HL7 v2 data.
Accepts one or a sequence of LA2 records and returns a value, collection or map of HL7 v2 data.
(map->la2 m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxa.la2, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxa.la2, taking a map of keywords to field values.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxa.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxa.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of treatment administration data and returns a record of RXA segment data.
Accepts a record of treatment administration data and returns a record of RXA segment data.
(string->action-code code-key)Returns the RXA action code that matches the provided keyword or string or nil if no match was found.
Returns the RXA action code that matches the provided keyword or string or nil if no match was found.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |