(->record rx-component-type
component-code
component-amount
component-units
component-strength
component-strength-units
supplementary-code
component-drug-strength-volume
component-drug-strength-volume-units)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxc.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxc.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts a RXC segment of parsed HL7 segment data and returns a RXC record.
Accepts a RXC segment of parsed HL7 segment data and returns a RXC record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxc.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxc.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of RXC data and returns a map of RXC segment data.
Accepts a record of RXC data and returns a map of RXC segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |