(->record quantity-timing
give-code
give-amount-minimum
give-amount-maximum
give-units
give-dosage-form
providers-administration-instructions
deliver-to-location
substitution-status
dispense-amount
dispense-units
number-of-refills
ordering-providers-dea-number
pharmacist-treatment-suppliers-verifier-id
prescription-number
number-of-refills-remaining
number-of-refills-doses-dispensed
dt-of-most-recent-refill-or-dose-dispensed
total-daily-dose
needs-human-review
&
overage)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxe.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxe.record.
(->record
quantity-timing
give-code
give-amount-minimum
give-amount-maximum
give-units
give-dosage-form
providers-administration-instructions
deliver-to-location
substitution-status
dispense-amount
dispense-units
number-of-refills
ordering-providers-dea-number
pharmacist-treatment-suppliers-verifier-id
prescription-number
number-of-refills-remaining
number-of-refills-doses-dispensed
dt-of-most-recent-refill-or-dose-dispensed
total-daily-dose
needs-human-review
pharmacy-treatment-suppliers-special-dispensing-instructions
give-per-time-unit
give-rate-amount
give-rate-units
give-strength
give-strength-units
give-indication
dispense-package-size
dispense-package-size-unit
dispense-package-method
supplementary-code
original-order-date-time
give-drug-strength-volume
give-drug-strength-volume-units
controlled-substance-schedule
formulary-status
pharmaceutical-substance-alternative
pharmacy-of-most-recent-fill
initial-dispense-amount
dispensing-pharmacy
dispensing-pharmacy-address
deliver-to-patient-location
deliver-to-address
pharmacy-order-type
pharmacy-phone-number)Positional factory function for com.nervestaple.clinical.message-intermediate.segment.rxe/record.
Positional factory function for com.nervestaple.clinical.message-intermediate.segment.rxe/record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts a RXC segment of parsed HL7 segment data and returns a RXC record.
Accepts a RXC segment of parsed HL7 segment data and returns a RXC record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxe.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxe.record, taking a map of keywords to field values.
(map->record G__26667)Factory function for com.nervestaple.clinical.message-intermediate.segment.rxe/record, taking a map of keywords to field values.
Factory function for com.nervestaple.clinical.message-intermediate.segment.rxe/record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of RXE data and returns a map of RXE segment data.
Accepts a record of RXE data and returns a map of RXE segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |