com.nervestaple.clinical.message-intermediate.segment.rxe


->recordclj

(->record quantity-timing
          give-code
          give-amount-minimum
          give-amount-maximum
          give-units
          give-dosage-form
          providers-administration-instructions
          deliver-to-location
          substitution-status
          dispense-amount
          dispense-units
          number-of-refills
          ordering-providers-dea-number
          pharmacist-treatment-suppliers-verifier-id
          prescription-number
          number-of-refills-remaining
          number-of-refills-doses-dispensed
          dt-of-most-recent-refill-or-dose-dispensed
          total-daily-dose
          needs-human-review
          &
          overage)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxe.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxe.record.
sourceraw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

hl7->recordclj

(hl7->record segment)

Accepts a RXC segment of parsed HL7 segment data and returns a RXC record.

Accepts a RXC segment of parsed HL7 segment data and returns a RXC record.
sourceraw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxe.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxe.record, taking a map of keywords to field values.
sourceraw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of RXE data and returns a map of RXE segment data.

Accepts a record of RXE data and returns a map of RXE segment data.
sourceraw docstring

SEGMENT-IDclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries