com.nervestaple.clinical.message-intermediate.segment.rxr


->recordclj

(->record route admin-site admin-device admin-method routing-instruction)

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxr.record.

Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxr.record.
sourceraw docstring

createclj

(create data-map)

Creates a new record using the provided map of segment data.

Creates a new record using the provided map of segment data.
sourceraw docstring

hl7->recordclj

(hl7->record segment)

Accepts an RXR segment of parsed HL7 v2 data and returns an RCR record.

Accepts an RXR segment of parsed HL7 v2 data and returns an RCR record.
sourceraw docstring

map->recordclj

(map->record m__7972__auto__)

Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxr.record, taking a map of keywords to field values.

Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxr.record, taking a map of keywords to field values.
sourceraw docstring

record->hl7clj

(record->hl7 record)

Accepts a record of treatment route data and returns a record of RXR segment data.

Accepts a record of treatment route data and returns a record of RXR segment
data.
sourceraw docstring

SEGMENT-IDclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries