(->record route admin-site admin-device admin-method routing-instruction)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxr.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.rxr.record.
(create data-map)Creates a new record using the provided map of segment data.
Creates a new record using the provided map of segment data.
(hl7->record segment)Accepts an RXR segment of parsed HL7 v2 data and returns an RCR record.
Accepts an RXR segment of parsed HL7 v2 data and returns an RCR record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxr.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.rxr.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of treatment route data and returns a record of RXR segment data.
Accepts a record of treatment route data and returns a record of RXR segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |