(->record vendor
release-number
product
identifier
product-information
install-date)Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.sft.record.
Positional factory function for class com.nervestaple.clinical.message_intermediate.segment.sft.record.
(hl7->record segment)Accepts a segment of parsed SFT data and returns an SFT record.
Accepts a segment of parsed SFT data and returns an SFT record.
(map->record m__7972__auto__)Factory function for class com.nervestaple.clinical.message_intermediate.segment.sft.record, taking a map of keywords to field values.
Factory function for class com.nervestaple.clinical.message_intermediate.segment.sft.record, taking a map of keywords to field values.
(record->hl7 record)Accepts a record of software data and returns a map of SFT segment data.
Accepts a record of software data and returns a map of SFT segment data.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |