(all-vectors? data)Returns true if the provided item is a vector where each element is another vector.
Returns true if the provided item is a vector where each element is another vector.
Map with our default set of delimiters
Map with our default set of delimiters
(get-or-nil vec index)Returns the value at the given index of the provided vector or a nil if there is no index or if the value equals "".
Returns the value at the given index of the provided vector or a nil if there is no index or if the value equals "".
(is-field? field)Returns true if the provided HL7 field data is a map of field data or false if it's an atom or sequence of data. Typically this would be used to test if a field is repeating.
Returns true if the provided HL7 field data is a map of field data or false if it's an atom or sequence of data. Typically this would be used to test if a field is repeating.
(map-nil-or-empty map-this)Returns true if all of the values of the map are either nil or empty string ("").
Returns true if all of the values of the map are either nil or empty
string ("").(parse-phone phone)Parses a phone number and returns a list of HL7 messaging phone number values:
[country-code area-code phone-number extension]
The extension must be preceded by an upper or lowercase "x".
Parses a phone number and returns a list of HL7 messaging phone number values:
[country-code area-code phone-number extension]
The extension must be preceded by an upper or lowercase "x".(read-string text)Reads the provided text, returning a String, number, etc.
Reads the provided text, returning a String, number, etc.
(trim-nils coll)(trim-nils coll no-empty-set)Removes any nil or empty set values at the end of a collection. For
instance, for the vector [1 2 3 nil nil nil] this function would return
[1 2 3]. If the optional no-empty-set parameter is set to true, then
nil will be returned instead of an empty set.
Removes any `nil` or empty set values at the end of a collection. For instance, for the vector [1 2 3 nil nil nil] this function would return [1 2 3]. If the optional `no-empty-set` parameter is set to true, then nil will be returned instead of an empty set.
(unwrap-and-first field)Accepts a field of parsed HL7 v2 data, which may be one item of data or a sequence of data items, and unwraps either the single item or each item in the sequence and returns only the first data item.
Accepts a field of parsed HL7 v2 data, which may be one item of data or a sequence of data items, and unwraps either the single item or each item in the sequence and returns only the first data item.
(unwrap-field field)Accepts a field of parsed HL7 v2 data, which may be one item of data or a sequence of data items, and unwraps either the single item or each item in the sequence and returns the data either the single item or vector of items.
Accepts a field of parsed HL7 v2 data, which may be one item of data or a sequence of data items, and unwraps either the single item or each item in the sequence and returns the data either the single item or vector of items.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |