com.nervestaple.clinical.message-intermediate.segment.utility


all-vectors?clj

(all-vectors? data)

Returns true if the provided item is a vector where each element is another vector.

Returns true if the provided item is a vector where each element is another
vector.
raw docstring

date-format-hl7clj

HL7 v2 date format.

HL7 v2 date format.
raw docstring

date-format-hl7-fallbackclj

HL7 v2 date format.

HL7 v2 date format.
raw docstring

date-format-short-hl7clj

HL7 v2 short date format.

HL7 v2 short date format.
raw docstring

default-delimitersclj

Map with our default set of delimiters

Map with our default set of delimiters
raw docstring

format-dateclj

(format-date date)

Formats the provided date into an HL7 messaging date, delegates to the format-time function.

Formats the provided date into an HL7 messaging date, delegates to the
`format-time` function.
raw docstring

format-timeclj

(format-time time)

Formats the provided date and time into an HL7 messaging date.

Formats the provided date and time into an HL7 messaging date.
raw docstring

get-or-nilclj

(get-or-nil vec index)

Returns the value at the given index of the provided vector or a nil if there is no index or if the value equals "".

Returns the value at the given index of the provided vector or a nil if there
is no index or if the value equals "".
raw docstring

is-field?clj

(is-field? field)

Returns true if the provided HL7 field data is a map of field data or false if it's an atom or sequence of data. Typically this would be used to test if a field is repeating.

Returns true if the provided HL7 field data is a map of field data or false if
it's an atom or sequence of data. Typically this would be used to test if a
field is repeating.
raw docstring

map-nil-or-emptyclj

(map-nil-or-empty map-this)

Returns true if all of the values of the map are either nil or empty string ("").

Returns true if all of the values of the map are either nil or empty
string ("").
raw docstring

padclj

(pad size coll value)

Pads a collection that should be the provided size by appending the specified value until that collection is the required size.

Pads a collection that should be the provided size by appending the specified
value until that collection is the required size.
raw docstring

parse-dateclj

(parse-date date-string)

Parsed an HL7 v2 formatted field or string with a date into a local date, delegates to the parse-timestamp function. If the value cannot be parsed, it is returned unaltered.

Parsed an HL7 v2 formatted field or string with a date into a local date,
delegates to the `parse-timestamp` function. If the value cannot be parsed,
it is returned unaltered.
raw docstring

parse-phoneclj

(parse-phone phone)

Parses a phone number and returns a list of HL7 messaging phone number values:

[country-code area-code phone-number extension]

The extension must be preceded by an upper or lowercase "x".

Parses a phone number and returns a list of HL7 messaging phone number values:

    [country-code area-code phone-number extension]

The extension must be preceded by an upper or lowercase "x".
raw docstring

parse-timestampclj

(parse-timestamp timestamp-in)

Parses an HL7 v2 formatted field or string with a date or timestamp into a local date, local date time or a zoned local date and time. If the value cannot be parsed, it is returned unaltered.

Parses an HL7 v2 formatted field or string with a date or timestamp into a
local date, local date time or a zoned local date and time. If the value
cannot be parsed, it is returned unaltered.
raw docstring

read-stringclj

(read-string text)

Reads the provided text, returning a String, number, etc.

Reads the provided text, returning a String, number, etc.
raw docstring

timestamp-format-hl7clj

HL7 v2 timestamp format, note that it does not include the time zone.

HL7 v2 timestamp format, note that it does not include the time zone.
raw docstring

timestamp-format-med-hl7clj

HL7 v2 timestamp format, note that it does not include the time zone.

HL7 v2 timestamp format, note that it does not include the time zone.
raw docstring

timestamp-format-short-hl7clj

HL7 v2 timestamp format, without seconds

HL7 v2 timestamp format, without seconds
raw docstring

timestamp-zoned-format-hl7clj

HL7 v2 timestamp format, note that it includes the time zone.

HL7 v2 timestamp format, note that it includes the time zone.
raw docstring

trim-nilsclj

(trim-nils coll)
(trim-nils coll no-empty-set)

Removes any nil or empty set values at the end of a collection. For instance, for the vector [1 2 3 nil nil nil] this function would return [1 2 3]. If the optional no-empty-set parameter is set to true, then nil will be returned instead of an empty set.

Removes any `nil` or empty set values at the end of a collection. For
instance, for the vector [1 2 3 nil nil nil] this function would return
[1 2 3]. If the optional `no-empty-set` parameter is set to true, then
nil will be returned instead of an empty set.
raw docstring

unwrap-and-firstclj

(unwrap-and-first field)

Accepts a field of parsed HL7 v2 data, which may be one item of data or a sequence of data items, and unwraps either the single item or each item in the sequence and returns only the first data item.

Accepts a field of parsed HL7 v2 data, which may be one item of data or a
sequence of data items, and unwraps either the single item or each item in the
sequence and returns only the first data item.
raw docstring

unwrap-fieldclj

(unwrap-field field)

Accepts a field of parsed HL7 v2 data, which may be one item of data or a sequence of data items, and unwraps either the single item or each item in the sequence and returns the data either the single item or vector of items.

Accepts a field of parsed HL7 v2 data, which may be one item of data or a
sequence of data items, and unwraps either the single item or each item in the
sequence and returns the data either the single item or vector of items.
raw docstring

vector-of-vector?clj

(vector-of-vector? data)

Returns true if the provided item is a vector that contains one or more vector instances.

Returns true if the provided item is a vector that contains one or more vector
instances.
raw docstring

year-format-short-hl7clj

HL7 v2 even shorter date format, only the year.

HL7 v2 even shorter date format, only the year.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries