(current-time)Returns the current time with a time zone
Returns the current time with a time zone
Default HL7 Messaging specification version
Default HL7 Messaging specification version
(filter-segment-id segment-id messages)Filters incoming messages by including only those messages that have at least one segment with the matching segment identifier.
Filters incoming messages by including only those messages that have at least one segment with the matching segment identifier.
Formatter for HL7 messaging timestamps
Formatter for HL7 messaging timestamps
(parse-date date)Parses a date in the format YYYY-MM-DD into an HL7 date
Parses a date in the format YYYY-MM-DD into an HL7 date
(parse-phones phone-map email-addresses)Parses a map of incoming phone data and a set of email addresses into a set of HL7 messaging fields
Parses a map of incoming phone data and a set of email addresses into a set of HL7 messaging fields
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |